# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V1alpha2PodSchedulingContextSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'potential_nodes': 'list[str]',
        'selected_node': 'str'
    }

    attribute_map = {
        'potential_nodes': 'potentialNodes',
        'selected_node': 'selectedNode'
    }

    def __init__(self, potential_nodes=None, selected_node=None, local_vars_configuration=None):  # noqa: E501
        """V1alpha2PodSchedulingContextSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._potential_nodes = None
        self._selected_node = None
        self.discriminator = None

        if potential_nodes is not None:
            self.potential_nodes = potential_nodes
        if selected_node is not None:
            self.selected_node = selected_node

    @property
    def potential_nodes(self):
        """Gets the potential_nodes of this V1alpha2PodSchedulingContextSpec.  # noqa: E501

        PotentialNodes lists nodes where the Pod might be able to run.  The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.  # noqa: E501

        :return: The potential_nodes of this V1alpha2PodSchedulingContextSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._potential_nodes

    @potential_nodes.setter
    def potential_nodes(self, potential_nodes):
        """Sets the potential_nodes of this V1alpha2PodSchedulingContextSpec.

        PotentialNodes lists nodes where the Pod might be able to run.  The size of this field is limited to 128. This is large enough for many clusters. Larger clusters may need more attempts to find a node that suits all pending resources. This may get increased in the future, but not reduced.  # noqa: E501

        :param potential_nodes: The potential_nodes of this V1alpha2PodSchedulingContextSpec.  # noqa: E501
        :type: list[str]
        """

        self._potential_nodes = potential_nodes

    @property
    def selected_node(self):
        """Gets the selected_node of this V1alpha2PodSchedulingContextSpec.  # noqa: E501

        SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use \"WaitForFirstConsumer\" allocation is to be attempted.  # noqa: E501

        :return: The selected_node of this V1alpha2PodSchedulingContextSpec.  # noqa: E501
        :rtype: str
        """
        return self._selected_node

    @selected_node.setter
    def selected_node(self, selected_node):
        """Sets the selected_node of this V1alpha2PodSchedulingContextSpec.

        SelectedNode is the node for which allocation of ResourceClaims that are referenced by the Pod and that use \"WaitForFirstConsumer\" allocation is to be attempted.  # noqa: E501

        :param selected_node: The selected_node of this V1alpha2PodSchedulingContextSpec.  # noqa: E501
        :type: str
        """

        self._selected_node = selected_node

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha2PodSchedulingContextSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1alpha2PodSchedulingContextSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V2HorizontalPodAutoscalerSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'behavior': 'V2HorizontalPodAutoscalerBehavior',
        'max_replicas': 'int',
        'metrics': 'list[V2MetricSpec]',
        'min_replicas': 'int',
        'scale_target_ref': 'V2CrossVersionObjectReference'
    }

    attribute_map = {
        'behavior': 'behavior',
        'max_replicas': 'maxReplicas',
        'metrics': 'metrics',
        'min_replicas': 'minReplicas',
        'scale_target_ref': 'scaleTargetRef'
    }

    def __init__(self, behavior=None, max_replicas=None, metrics=None, min_replicas=None, scale_target_ref=None, local_vars_configuration=None):  # noqa: E501
        """V2HorizontalPodAutoscalerSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._behavior = None
        self._max_replicas = None
        self._metrics = None
        self._min_replicas = None
        self._scale_target_ref = None
        self.discriminator = None

        if behavior is not None:
            self.behavior = behavior
        self.max_replicas = max_replicas
        if metrics is not None:
            self.metrics = metrics
        if min_replicas is not None:
            self.min_replicas = min_replicas
        self.scale_target_ref = scale_target_ref

    @property
    def behavior(self):
        """Gets the behavior of this V2HorizontalPodAutoscalerSpec.  # noqa: E501


        :return: The behavior of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :rtype: V2HorizontalPodAutoscalerBehavior
        """
        return self._behavior

    @behavior.setter
    def behavior(self, behavior):
        """Sets the behavior of this V2HorizontalPodAutoscalerSpec.


        :param behavior: The behavior of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :type: V2HorizontalPodAutoscalerBehavior
        """

        self._behavior = behavior

    @property
    def max_replicas(self):
        """Gets the max_replicas of this V2HorizontalPodAutoscalerSpec.  # noqa: E501

        maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.  # noqa: E501

        :return: The max_replicas of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :rtype: int
        """
        return self._max_replicas

    @max_replicas.setter
    def max_replicas(self, max_replicas):
        """Sets the max_replicas of this V2HorizontalPodAutoscalerSpec.

        maxReplicas is the upper limit for the number of replicas to which the autoscaler can scale up. It cannot be less that minReplicas.  # noqa: E501

        :param max_replicas: The max_replicas of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and max_replicas is None:  # noqa: E501
            raise ValueError("Invalid value for `max_replicas`, must not be `None`")  # noqa: E501

        self._max_replicas = max_replicas

    @property
    def metrics(self):
        """Gets the metrics of this V2HorizontalPodAutoscalerSpec.  # noqa: E501

        metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization.  # noqa: E501

        :return: The metrics of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :rtype: list[V2MetricSpec]
        """
        return self._metrics

    @metrics.setter
    def metrics(self, metrics):
        """Sets the metrics of this V2HorizontalPodAutoscalerSpec.

        metrics contains the specifications for which to use to calculate the desired replica count (the maximum replica count across all metrics will be used).  The desired replica count is calculated multiplying the ratio between the target value and the current value by the current number of pods.  Ergo, metrics used must decrease as the pod count is increased, and vice-versa.  See the individual metric source types for more information about how each type of metric must respond. If not set, the default metric will be set to 80% average CPU utilization.  # noqa: E501

        :param metrics: The metrics of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :type: list[V2MetricSpec]
        """

        self._metrics = metrics

    @property
    def min_replicas(self):
        """Gets the min_replicas of this V2HorizontalPodAutoscalerSpec.  # noqa: E501

        minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.  # noqa: E501

        :return: The min_replicas of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :rtype: int
        """
        return self._min_replicas

    @min_replicas.setter
    def min_replicas(self, min_replicas):
        """Sets the min_replicas of this V2HorizontalPodAutoscalerSpec.

        minReplicas is the lower limit for the number of replicas to which the autoscaler can scale down.  It defaults to 1 pod.  minReplicas is allowed to be 0 if the alpha feature gate HPAScaleToZero is enabled and at least one Object or External metric is configured.  Scaling is active as long as at least one metric value is available.  # noqa: E501

        :param min_replicas: The min_replicas of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :type: int
        """

        self._min_replicas = min_replicas

    @property
    def scale_target_ref(self):
        """Gets the scale_target_ref of this V2HorizontalPodAutoscalerSpec.  # noqa: E501


        :return: The scale_target_ref of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :rtype: V2CrossVersionObjectReference
        """
        return self._scale_target_ref

    @scale_target_ref.setter
    def scale_target_ref(self, scale_target_ref):
        """Sets the scale_target_ref of this V2HorizontalPodAutoscalerSpec.


        :param scale_target_ref: The scale_target_ref of this V2HorizontalPodAutoscalerSpec.  # noqa: E501
        :type: V2CrossVersionObjectReference
        """
        if self.local_vars_configuration.client_side_validation and scale_target_ref is None:  # noqa: E501
            raise ValueError("Invalid value for `scale_target_ref`, must not be `None`")  # noqa: E501

        self._scale_target_ref = scale_target_ref

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V2HorizontalPodAutoscalerSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V2HorizontalPodAutoscalerSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V1alpha1ValidatingAdmissionPolicyBindingSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'match_resources': 'V1alpha1MatchResources',
        'param_ref': 'V1alpha1ParamRef',
        'policy_name': 'str',
        'validation_actions': 'list[str]'
    }

    attribute_map = {
        'match_resources': 'matchResources',
        'param_ref': 'paramRef',
        'policy_name': 'policyName',
        'validation_actions': 'validationActions'
    }

    def __init__(self, match_resources=None, param_ref=None, policy_name=None, validation_actions=None, local_vars_configuration=None):  # noqa: E501
        """V1alpha1ValidatingAdmissionPolicyBindingSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._match_resources = None
        self._param_ref = None
        self._policy_name = None
        self._validation_actions = None
        self.discriminator = None

        if match_resources is not None:
            self.match_resources = match_resources
        if param_ref is not None:
            self.param_ref = param_ref
        if policy_name is not None:
            self.policy_name = policy_name
        if validation_actions is not None:
            self.validation_actions = validation_actions

    @property
    def match_resources(self):
        """Gets the match_resources of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501


        :return: The match_resources of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :rtype: V1alpha1MatchResources
        """
        return self._match_resources

    @match_resources.setter
    def match_resources(self, match_resources):
        """Sets the match_resources of this V1alpha1ValidatingAdmissionPolicyBindingSpec.


        :param match_resources: The match_resources of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :type: V1alpha1MatchResources
        """

        self._match_resources = match_resources

    @property
    def param_ref(self):
        """Gets the param_ref of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501


        :return: The param_ref of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :rtype: V1alpha1ParamRef
        """
        return self._param_ref

    @param_ref.setter
    def param_ref(self, param_ref):
        """Sets the param_ref of this V1alpha1ValidatingAdmissionPolicyBindingSpec.


        :param param_ref: The param_ref of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :type: V1alpha1ParamRef
        """

        self._param_ref = param_ref

    @property
    def policy_name(self):
        """Gets the policy_name of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501

        PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.  # noqa: E501

        :return: The policy_name of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :rtype: str
        """
        return self._policy_name

    @policy_name.setter
    def policy_name(self, policy_name):
        """Sets the policy_name of this V1alpha1ValidatingAdmissionPolicyBindingSpec.

        PolicyName references a ValidatingAdmissionPolicy name which the ValidatingAdmissionPolicyBinding binds to. If the referenced resource does not exist, this binding is considered invalid and will be ignored Required.  # noqa: E501

        :param policy_name: The policy_name of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :type: str
        """

        self._policy_name = policy_name

    @property
    def validation_actions(self):
        """Gets the validation_actions of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501

        validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.  Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.  validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.  The supported actions values are:  \"Deny\" specifies that a validation failure results in a denied request.  \"Warn\" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.  \"Audit\" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `\"validation.policy.admission.k8s.io/validation_failure\": \"[{\"message\": \"Invalid value\", {\"policy\": \"policy.example.com\", {\"binding\": \"policybinding.example.com\", {\"expressionIndex\": \"1\", {\"validationActions\": [\"Audit\"]}]\"`  Clients should expect to handle additional values by ignoring any values not recognized.  \"Deny\" and \"Warn\" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.  Required.  # noqa: E501

        :return: The validation_actions of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._validation_actions

    @validation_actions.setter
    def validation_actions(self, validation_actions):
        """Sets the validation_actions of this V1alpha1ValidatingAdmissionPolicyBindingSpec.

        validationActions declares how Validations of the referenced ValidatingAdmissionPolicy are enforced. If a validation evaluates to false it is always enforced according to these actions.  Failures defined by the ValidatingAdmissionPolicy's FailurePolicy are enforced according to these actions only if the FailurePolicy is set to Fail, otherwise the failures are ignored. This includes compilation errors, runtime errors and misconfigurations of the policy.  validationActions is declared as a set of action values. Order does not matter. validationActions may not contain duplicates of the same action.  The supported actions values are:  \"Deny\" specifies that a validation failure results in a denied request.  \"Warn\" specifies that a validation failure is reported to the request client in HTTP Warning headers, with a warning code of 299. Warnings can be sent both for allowed or denied admission responses.  \"Audit\" specifies that a validation failure is included in the published audit event for the request. The audit event will contain a `validation.policy.admission.k8s.io/validation_failure` audit annotation with a value containing the details of the validation failures, formatted as a JSON list of objects, each with the following fields: - message: The validation failure message string - policy: The resource name of the ValidatingAdmissionPolicy - binding: The resource name of the ValidatingAdmissionPolicyBinding - expressionIndex: The index of the failed validations in the ValidatingAdmissionPolicy - validationActions: The enforcement actions enacted for the validation failure Example audit annotation: `\"validation.policy.admission.k8s.io/validation_failure\": \"[{\"message\": \"Invalid value\", {\"policy\": \"policy.example.com\", {\"binding\": \"policybinding.example.com\", {\"expressionIndex\": \"1\", {\"validationActions\": [\"Audit\"]}]\"`  Clients should expect to handle additional values by ignoring any values not recognized.  \"Deny\" and \"Warn\" may not be used together since this combination needlessly duplicates the validation failure both in the API response body and the HTTP warning headers.  Required.  # noqa: E501

        :param validation_actions: The validation_actions of this V1alpha1ValidatingAdmissionPolicyBindingSpec.  # noqa: E501
        :type: list[str]
        """

        self._validation_actions = validation_actions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1alpha1ValidatingAdmissionPolicyBindingSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1alpha1ValidatingAdmissionPolicyBindingSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V1CSIStorageCapacity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_version': 'str',
        'capacity': 'str',
        'kind': 'str',
        'maximum_volume_size': 'str',
        'metadata': 'V1ObjectMeta',
        'node_topology': 'V1LabelSelector',
        'storage_class_name': 'str'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'capacity': 'capacity',
        'kind': 'kind',
        'maximum_volume_size': 'maximumVolumeSize',
        'metadata': 'metadata',
        'node_topology': 'nodeTopology',
        'storage_class_name': 'storageClassName'
    }

    def __init__(self, api_version=None, capacity=None, kind=None, maximum_volume_size=None, metadata=None, node_topology=None, storage_class_name=None, local_vars_configuration=None):  # noqa: E501
        """V1CSIStorageCapacity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_version = None
        self._capacity = None
        self._kind = None
        self._maximum_volume_size = None
        self._metadata = None
        self._node_topology = None
        self._storage_class_name = None
        self.discriminator = None

        if api_version is not None:
            self.api_version = api_version
        if capacity is not None:
            self.capacity = capacity
        if kind is not None:
            self.kind = kind
        if maximum_volume_size is not None:
            self.maximum_volume_size = maximum_volume_size
        if metadata is not None:
            self.metadata = metadata
        if node_topology is not None:
            self.node_topology = node_topology
        self.storage_class_name = storage_class_name

    @property
    def api_version(self):
        """Gets the api_version of this V1CSIStorageCapacity.  # noqa: E501

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources  # noqa: E501

        :return: The api_version of this V1CSIStorageCapacity.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this V1CSIStorageCapacity.

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources  # noqa: E501

        :param api_version: The api_version of this V1CSIStorageCapacity.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def capacity(self):
        """Gets the capacity of this V1CSIStorageCapacity.  # noqa: E501

        capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.  The semantic is currently (CSI spec 1.2) defined as: The available capacity, in bytes, of the storage that can be used to provision volumes. If not set, that information is currently unavailable.  # noqa: E501

        :return: The capacity of this V1CSIStorageCapacity.  # noqa: E501
        :rtype: str
        """
        return self._capacity

    @capacity.setter
    def capacity(self, capacity):
        """Sets the capacity of this V1CSIStorageCapacity.

        capacity is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.  The semantic is currently (CSI spec 1.2) defined as: The available capacity, in bytes, of the storage that can be used to provision volumes. If not set, that information is currently unavailable.  # noqa: E501

        :param capacity: The capacity of this V1CSIStorageCapacity.  # noqa: E501
        :type: str
        """

        self._capacity = capacity

    @property
    def kind(self):
        """Gets the kind of this V1CSIStorageCapacity.  # noqa: E501

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds  # noqa: E501

        :return: The kind of this V1CSIStorageCapacity.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1CSIStorageCapacity.

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds  # noqa: E501

        :param kind: The kind of this V1CSIStorageCapacity.  # noqa: E501
        :type: str
        """

        self._kind = kind

    @property
    def maximum_volume_size(self):
        """Gets the maximum_volume_size of this V1CSIStorageCapacity.  # noqa: E501

        maximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.  This is defined since CSI spec 1.4.0 as the largest size that may be used in a CreateVolumeRequest.capacity_range.required_bytes field to create a volume with the same parameters as those in GetCapacityRequest. The corresponding value in the Kubernetes API is ResourceRequirements.Requests in a volume claim.  # noqa: E501

        :return: The maximum_volume_size of this V1CSIStorageCapacity.  # noqa: E501
        :rtype: str
        """
        return self._maximum_volume_size

    @maximum_volume_size.setter
    def maximum_volume_size(self, maximum_volume_size):
        """Sets the maximum_volume_size of this V1CSIStorageCapacity.

        maximumVolumeSize is the value reported by the CSI driver in its GetCapacityResponse for a GetCapacityRequest with topology and parameters that match the previous fields.  This is defined since CSI spec 1.4.0 as the largest size that may be used in a CreateVolumeRequest.capacity_range.required_bytes field to create a volume with the same parameters as those in GetCapacityRequest. The corresponding value in the Kubernetes API is ResourceRequirements.Requests in a volume claim.  # noqa: E501

        :param maximum_volume_size: The maximum_volume_size of this V1CSIStorageCapacity.  # noqa: E501
        :type: str
        """

        self._maximum_volume_size = maximum_volume_size

    @property
    def metadata(self):
        """Gets the metadata of this V1CSIStorageCapacity.  # noqa: E501


        :return: The metadata of this V1CSIStorageCapacity.  # noqa: E501
        :rtype: V1ObjectMeta
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this V1CSIStorageCapacity.


        :param metadata: The metadata of this V1CSIStorageCapacity.  # noqa: E501
        :type: V1ObjectMeta
        """

        self._metadata = metadata

    @property
    def node_topology(self):
        """Gets the node_topology of this V1CSIStorageCapacity.  # noqa: E501


        :return: The node_topology of this V1CSIStorageCapacity.  # noqa: E501
        :rtype: V1LabelSelector
        """
        return self._node_topology

    @node_topology.setter
    def node_topology(self, node_topology):
        """Sets the node_topology of this V1CSIStorageCapacity.


        :param node_topology: The node_topology of this V1CSIStorageCapacity.  # noqa: E501
        :type: V1LabelSelector
        """

        self._node_topology = node_topology

    @property
    def storage_class_name(self):
        """Gets the storage_class_name of this V1CSIStorageCapacity.  # noqa: E501

        storageClassName represents the name of the StorageClass that the reported capacity applies to. It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable.  # noqa: E501

        :return: The storage_class_name of this V1CSIStorageCapacity.  # noqa: E501
        :rtype: str
        """
        return self._storage_class_name

    @storage_class_name.setter
    def storage_class_name(self, storage_class_name):
        """Sets the storage_class_name of this V1CSIStorageCapacity.

        storageClassName represents the name of the StorageClass that the reported capacity applies to. It must meet the same requirements as the name of a StorageClass object (non-empty, DNS subdomain). If that object no longer exists, the CSIStorageCapacity object is obsolete and should be removed by its creator. This field is immutable.  # noqa: E501

        :param storage_class_name: The storage_class_name of this V1CSIStorageCapacity.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and storage_class_name is None:  # noqa: E501
            raise ValueError("Invalid value for `storage_class_name`, must not be `None`")  # noqa: E501

        self._storage_class_name = storage_class_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1CSIStorageCapacity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1CSIStorageCapacity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V1Secret(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_version': 'str',
        'data': 'dict(str, str)',
        'immutable': 'bool',
        'kind': 'str',
        'metadata': 'V1ObjectMeta',
        'string_data': 'dict(str, str)',
        'type': 'str'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'data': 'data',
        'immutable': 'immutable',
        'kind': 'kind',
        'metadata': 'metadata',
        'string_data': 'stringData',
        'type': 'type'
    }

    def __init__(self, api_version=None, data=None, immutable=None, kind=None, metadata=None, string_data=None, type=None, local_vars_configuration=None):  # noqa: E501
        """V1Secret - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_version = None
        self._data = None
        self._immutable = None
        self._kind = None
        self._metadata = None
        self._string_data = None
        self._type = None
        self.discriminator = None

        if api_version is not None:
            self.api_version = api_version
        if data is not None:
            self.data = data
        if immutable is not None:
            self.immutable = immutable
        if kind is not None:
            self.kind = kind
        if metadata is not None:
            self.metadata = metadata
        if string_data is not None:
            self.string_data = string_data
        if type is not None:
            self.type = type

    @property
    def api_version(self):
        """Gets the api_version of this V1Secret.  # noqa: E501

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources  # noqa: E501

        :return: The api_version of this V1Secret.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this V1Secret.

        APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources  # noqa: E501

        :param api_version: The api_version of this V1Secret.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def data(self):
        """Gets the data of this V1Secret.  # noqa: E501

        Data contains the secret data. Each key must consist of alphanumeric characters, '-', '_' or '.'. The serialized form of the secret data is a base64 encoded string, representing the arbitrary (possibly non-string) data value here. Described in https://tools.ietf.org/html/rfc4648#section-4  # noqa: E501

        :return: The data of this V1Secret.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this V1Secret.

        Data contains the secret data. Each key must consist of alphanumeric characters, '-', '_' or '.'. The serialized form of the secret data is a base64 encoded string, representing the arbitrary (possibly non-string) data value here. Described in https://tools.ietf.org/html/rfc4648#section-4  # noqa: E501

        :param data: The data of this V1Secret.  # noqa: E501
        :type: dict(str, str)
        """

        self._data = data

    @property
    def immutable(self):
        """Gets the immutable of this V1Secret.  # noqa: E501

        Immutable, if set to true, ensures that data stored in the Secret cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil.  # noqa: E501

        :return: The immutable of this V1Secret.  # noqa: E501
        :rtype: bool
        """
        return self._immutable

    @immutable.setter
    def immutable(self, immutable):
        """Sets the immutable of this V1Secret.

        Immutable, if set to true, ensures that data stored in the Secret cannot be updated (only object metadata can be modified). If not set to true, the field can be modified at any time. Defaulted to nil.  # noqa: E501

        :param immutable: The immutable of this V1Secret.  # noqa: E501
        :type: bool
        """

        self._immutable = immutable

    @property
    def kind(self):
        """Gets the kind of this V1Secret.  # noqa: E501

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds  # noqa: E501

        :return: The kind of this V1Secret.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this V1Secret.

        Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds  # noqa: E501

        :param kind: The kind of this V1Secret.  # noqa: E501
        :type: str
        """

        self._kind = kind

    @property
    def metadata(self):
        """Gets the metadata of this V1Secret.  # noqa: E501


        :return: The metadata of this V1Secret.  # noqa: E501
        :rtype: V1ObjectMeta
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this V1Secret.


        :param metadata: The metadata of this V1Secret.  # noqa: E501
        :type: V1ObjectMeta
        """

        self._metadata = metadata

    @property
    def string_data(self):
        """Gets the string_data of this V1Secret.  # noqa: E501

        stringData allows specifying non-binary secret data in string form. It is provided as a write-only input field for convenience. All keys and values are merged into the data field on write, overwriting any existing values. The stringData field is never output when reading from the API.  # noqa: E501

        :return: The string_data of this V1Secret.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._string_data

    @string_data.setter
    def string_data(self, string_data):
        """Sets the string_data of this V1Secret.

        stringData allows specifying non-binary secret data in string form. It is provided as a write-only input field for convenience. All keys and values are merged into the data field on write, overwriting any existing values. The stringData field is never output when reading from the API.  # noqa: E501

        :param string_data: The string_data of this V1Secret.  # noqa: E501
        :type: dict(str, str)
        """

        self._string_data = string_data

    @property
    def type(self):
        """Gets the type of this V1Secret.  # noqa: E501

        Used to facilitate programmatic handling of secret data. More info: https://kubernetes.io/docs/concepts/configuration/secret/#secret-types  # noqa: E501

        :return: The type of this V1Secret.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1Secret.

        Used to facilitate programmatic handling of secret data. More info: https://kubernetes.io/docs/concepts/configuration/secret/#secret-types  # noqa: E501

        :param type: The type of this V1Secret.  # noqa: E501
        :type: str
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1Secret):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1Secret):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V1beta3ExemptPriorityLevelConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'lendable_percent': 'int',
        'nominal_concurrency_shares': 'int'
    }

    attribute_map = {
        'lendable_percent': 'lendablePercent',
        'nominal_concurrency_shares': 'nominalConcurrencyShares'
    }

    def __init__(self, lendable_percent=None, nominal_concurrency_shares=None, local_vars_configuration=None):  # noqa: E501
        """V1beta3ExemptPriorityLevelConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._lendable_percent = None
        self._nominal_concurrency_shares = None
        self.discriminator = None

        if lendable_percent is not None:
            self.lendable_percent = lendable_percent
        if nominal_concurrency_shares is not None:
            self.nominal_concurrency_shares = nominal_concurrency_shares

    @property
    def lendable_percent(self):
        """Gets the lendable_percent of this V1beta3ExemptPriorityLevelConfiguration.  # noqa: E501

        `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.  LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )  # noqa: E501

        :return: The lendable_percent of this V1beta3ExemptPriorityLevelConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._lendable_percent

    @lendable_percent.setter
    def lendable_percent(self, lendable_percent):
        """Sets the lendable_percent of this V1beta3ExemptPriorityLevelConfiguration.

        `lendablePercent` prescribes the fraction of the level's NominalCL that can be borrowed by other priority levels.  This value of this field must be between 0 and 100, inclusive, and it defaults to 0. The number of seats that other levels can borrow from this level, known as this level's LendableConcurrencyLimit (LendableCL), is defined as follows.  LendableCL(i) = round( NominalCL(i) * lendablePercent(i)/100.0 )  # noqa: E501

        :param lendable_percent: The lendable_percent of this V1beta3ExemptPriorityLevelConfiguration.  # noqa: E501
        :type: int
        """

        self._lendable_percent = lendable_percent

    @property
    def nominal_concurrency_shares(self):
        """Gets the nominal_concurrency_shares of this V1beta3ExemptPriorityLevelConfiguration.  # noqa: E501

        `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:  NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)  Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.  # noqa: E501

        :return: The nominal_concurrency_shares of this V1beta3ExemptPriorityLevelConfiguration.  # noqa: E501
        :rtype: int
        """
        return self._nominal_concurrency_shares

    @nominal_concurrency_shares.setter
    def nominal_concurrency_shares(self, nominal_concurrency_shares):
        """Sets the nominal_concurrency_shares of this V1beta3ExemptPriorityLevelConfiguration.

        `nominalConcurrencyShares` (NCS) contributes to the computation of the NominalConcurrencyLimit (NominalCL) of this level. This is the number of execution seats nominally reserved for this priority level. This DOES NOT limit the dispatching from this priority level but affects the other priority levels through the borrowing mechanism. The server's concurrency limit (ServerCL) is divided among all the priority levels in proportion to their NCS values:  NominalCL(i)  = ceil( ServerCL * NCS(i) / sum_ncs ) sum_ncs = sum[priority level k] NCS(k)  Bigger numbers mean a larger nominal concurrency limit, at the expense of every other priority level. This field has a default value of zero.  # noqa: E501

        :param nominal_concurrency_shares: The nominal_concurrency_shares of this V1beta3ExemptPriorityLevelConfiguration.  # noqa: E501
        :type: int
        """

        self._nominal_concurrency_shares = nominal_concurrency_shares

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta3ExemptPriorityLevelConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta3ExemptPriorityLevelConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V1EphemeralContainer(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'args': 'list[str]',
        'command': 'list[str]',
        'env': 'list[V1EnvVar]',
        'env_from': 'list[V1EnvFromSource]',
        'image': 'str',
        'image_pull_policy': 'str',
        'lifecycle': 'V1Lifecycle',
        'liveness_probe': 'V1Probe',
        'name': 'str',
        'ports': 'list[V1ContainerPort]',
        'readiness_probe': 'V1Probe',
        'resize_policy': 'list[V1ContainerResizePolicy]',
        'resources': 'V1ResourceRequirements',
        'restart_policy': 'str',
        'security_context': 'V1SecurityContext',
        'startup_probe': 'V1Probe',
        'stdin': 'bool',
        'stdin_once': 'bool',
        'target_container_name': 'str',
        'termination_message_path': 'str',
        'termination_message_policy': 'str',
        'tty': 'bool',
        'volume_devices': 'list[V1VolumeDevice]',
        'volume_mounts': 'list[V1VolumeMount]',
        'working_dir': 'str'
    }

    attribute_map = {
        'args': 'args',
        'command': 'command',
        'env': 'env',
        'env_from': 'envFrom',
        'image': 'image',
        'image_pull_policy': 'imagePullPolicy',
        'lifecycle': 'lifecycle',
        'liveness_probe': 'livenessProbe',
        'name': 'name',
        'ports': 'ports',
        'readiness_probe': 'readinessProbe',
        'resize_policy': 'resizePolicy',
        'resources': 'resources',
        'restart_policy': 'restartPolicy',
        'security_context': 'securityContext',
        'startup_probe': 'startupProbe',
        'stdin': 'stdin',
        'stdin_once': 'stdinOnce',
        'target_container_name': 'targetContainerName',
        'termination_message_path': 'terminationMessagePath',
        'termination_message_policy': 'terminationMessagePolicy',
        'tty': 'tty',
        'volume_devices': 'volumeDevices',
        'volume_mounts': 'volumeMounts',
        'working_dir': 'workingDir'
    }

    def __init__(self, args=None, command=None, env=None, env_from=None, image=None, image_pull_policy=None, lifecycle=None, liveness_probe=None, name=None, ports=None, readiness_probe=None, resize_policy=None, resources=None, restart_policy=None, security_context=None, startup_probe=None, stdin=None, stdin_once=None, target_container_name=None, termination_message_path=None, termination_message_policy=None, tty=None, volume_devices=None, volume_mounts=None, working_dir=None, local_vars_configuration=None):  # noqa: E501
        """V1EphemeralContainer - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._args = None
        self._command = None
        self._env = None
        self._env_from = None
        self._image = None
        self._image_pull_policy = None
        self._lifecycle = None
        self._liveness_probe = None
        self._name = None
        self._ports = None
        self._readiness_probe = None
        self._resize_policy = None
        self._resources = None
        self._restart_policy = None
        self._security_context = None
        self._startup_probe = None
        self._stdin = None
        self._stdin_once = None
        self._target_container_name = None
        self._termination_message_path = None
        self._termination_message_policy = None
        self._tty = None
        self._volume_devices = None
        self._volume_mounts = None
        self._working_dir = None
        self.discriminator = None

        if args is not None:
            self.args = args
        if command is not None:
            self.command = command
        if env is not None:
            self.env = env
        if env_from is not None:
            self.env_from = env_from
        if image is not None:
            self.image = image
        if image_pull_policy is not None:
            self.image_pull_policy = image_pull_policy
        if lifecycle is not None:
            self.lifecycle = lifecycle
        if liveness_probe is not None:
            self.liveness_probe = liveness_probe
        self.name = name
        if ports is not None:
            self.ports = ports
        if readiness_probe is not None:
            self.readiness_probe = readiness_probe
        if resize_policy is not None:
            self.resize_policy = resize_policy
        if resources is not None:
            self.resources = resources
        if restart_policy is not None:
            self.restart_policy = restart_policy
        if security_context is not None:
            self.security_context = security_context
        if startup_probe is not None:
            self.startup_probe = startup_probe
        if stdin is not None:
            self.stdin = stdin
        if stdin_once is not None:
            self.stdin_once = stdin_once
        if target_container_name is not None:
            self.target_container_name = target_container_name
        if termination_message_path is not None:
            self.termination_message_path = termination_message_path
        if termination_message_policy is not None:
            self.termination_message_policy = termination_message_policy
        if tty is not None:
            self.tty = tty
        if volume_devices is not None:
            self.volume_devices = volume_devices
        if volume_mounts is not None:
            self.volume_mounts = volume_mounts
        if working_dir is not None:
            self.working_dir = working_dir

    @property
    def args(self):
        """Gets the args of this V1EphemeralContainer.  # noqa: E501

        Arguments to the entrypoint. The image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. \"$$(VAR_NAME)\" will produce the string literal \"$(VAR_NAME)\". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell  # noqa: E501

        :return: The args of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[str]
        """
        return self._args

    @args.setter
    def args(self, args):
        """Sets the args of this V1EphemeralContainer.

        Arguments to the entrypoint. The image's CMD is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. \"$$(VAR_NAME)\" will produce the string literal \"$(VAR_NAME)\". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell  # noqa: E501

        :param args: The args of this V1EphemeralContainer.  # noqa: E501
        :type: list[str]
        """

        self._args = args

    @property
    def command(self):
        """Gets the command of this V1EphemeralContainer.  # noqa: E501

        Entrypoint array. Not executed within a shell. The image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. \"$$(VAR_NAME)\" will produce the string literal \"$(VAR_NAME)\". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell  # noqa: E501

        :return: The command of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[str]
        """
        return self._command

    @command.setter
    def command(self, command):
        """Sets the command of this V1EphemeralContainer.

        Entrypoint array. Not executed within a shell. The image's ENTRYPOINT is used if this is not provided. Variable references $(VAR_NAME) are expanded using the container's environment. If a variable cannot be resolved, the reference in the input string will be unchanged. Double $$ are reduced to a single $, which allows for escaping the $(VAR_NAME) syntax: i.e. \"$$(VAR_NAME)\" will produce the string literal \"$(VAR_NAME)\". Escaped references will never be expanded, regardless of whether the variable exists or not. Cannot be updated. More info: https://kubernetes.io/docs/tasks/inject-data-application/define-command-argument-container/#running-a-command-in-a-shell  # noqa: E501

        :param command: The command of this V1EphemeralContainer.  # noqa: E501
        :type: list[str]
        """

        self._command = command

    @property
    def env(self):
        """Gets the env of this V1EphemeralContainer.  # noqa: E501

        List of environment variables to set in the container. Cannot be updated.  # noqa: E501

        :return: The env of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env):
        """Sets the env of this V1EphemeralContainer.

        List of environment variables to set in the container. Cannot be updated.  # noqa: E501

        :param env: The env of this V1EphemeralContainer.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def env_from(self):
        """Gets the env_from of this V1EphemeralContainer.  # noqa: E501

        List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.  # noqa: E501

        :return: The env_from of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[V1EnvFromSource]
        """
        return self._env_from

    @env_from.setter
    def env_from(self, env_from):
        """Sets the env_from of this V1EphemeralContainer.

        List of sources to populate environment variables in the container. The keys defined within a source must be a C_IDENTIFIER. All invalid keys will be reported as an event when the container is starting. When a key exists in multiple sources, the value associated with the last source will take precedence. Values defined by an Env with a duplicate key will take precedence. Cannot be updated.  # noqa: E501

        :param env_from: The env_from of this V1EphemeralContainer.  # noqa: E501
        :type: list[V1EnvFromSource]
        """

        self._env_from = env_from

    @property
    def image(self):
        """Gets the image of this V1EphemeralContainer.  # noqa: E501

        Container image name. More info: https://kubernetes.io/docs/concepts/containers/images  # noqa: E501

        :return: The image of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this V1EphemeralContainer.

        Container image name. More info: https://kubernetes.io/docs/concepts/containers/images  # noqa: E501

        :param image: The image of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def image_pull_policy(self):
        """Gets the image_pull_policy of this V1EphemeralContainer.  # noqa: E501

        Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images  # noqa: E501

        :return: The image_pull_policy of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._image_pull_policy

    @image_pull_policy.setter
    def image_pull_policy(self, image_pull_policy):
        """Sets the image_pull_policy of this V1EphemeralContainer.

        Image pull policy. One of Always, Never, IfNotPresent. Defaults to Always if :latest tag is specified, or IfNotPresent otherwise. Cannot be updated. More info: https://kubernetes.io/docs/concepts/containers/images#updating-images  # noqa: E501

        :param image_pull_policy: The image_pull_policy of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """

        self._image_pull_policy = image_pull_policy

    @property
    def lifecycle(self):
        """Gets the lifecycle of this V1EphemeralContainer.  # noqa: E501


        :return: The lifecycle of this V1EphemeralContainer.  # noqa: E501
        :rtype: V1Lifecycle
        """
        return self._lifecycle

    @lifecycle.setter
    def lifecycle(self, lifecycle):
        """Sets the lifecycle of this V1EphemeralContainer.


        :param lifecycle: The lifecycle of this V1EphemeralContainer.  # noqa: E501
        :type: V1Lifecycle
        """

        self._lifecycle = lifecycle

    @property
    def liveness_probe(self):
        """Gets the liveness_probe of this V1EphemeralContainer.  # noqa: E501


        :return: The liveness_probe of this V1EphemeralContainer.  # noqa: E501
        :rtype: V1Probe
        """
        return self._liveness_probe

    @liveness_probe.setter
    def liveness_probe(self, liveness_probe):
        """Sets the liveness_probe of this V1EphemeralContainer.


        :param liveness_probe: The liveness_probe of this V1EphemeralContainer.  # noqa: E501
        :type: V1Probe
        """

        self._liveness_probe = liveness_probe

    @property
    def name(self):
        """Gets the name of this V1EphemeralContainer.  # noqa: E501

        Name of the ephemeral container specified as a DNS_LABEL. This name must be unique among all containers, init containers and ephemeral containers.  # noqa: E501

        :return: The name of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1EphemeralContainer.

        Name of the ephemeral container specified as a DNS_LABEL. This name must be unique among all containers, init containers and ephemeral containers.  # noqa: E501

        :param name: The name of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def ports(self):
        """Gets the ports of this V1EphemeralContainer.  # noqa: E501

        Ports are not allowed for ephemeral containers.  # noqa: E501

        :return: The ports of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[V1ContainerPort]
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this V1EphemeralContainer.

        Ports are not allowed for ephemeral containers.  # noqa: E501

        :param ports: The ports of this V1EphemeralContainer.  # noqa: E501
        :type: list[V1ContainerPort]
        """

        self._ports = ports

    @property
    def readiness_probe(self):
        """Gets the readiness_probe of this V1EphemeralContainer.  # noqa: E501


        :return: The readiness_probe of this V1EphemeralContainer.  # noqa: E501
        :rtype: V1Probe
        """
        return self._readiness_probe

    @readiness_probe.setter
    def readiness_probe(self, readiness_probe):
        """Sets the readiness_probe of this V1EphemeralContainer.


        :param readiness_probe: The readiness_probe of this V1EphemeralContainer.  # noqa: E501
        :type: V1Probe
        """

        self._readiness_probe = readiness_probe

    @property
    def resize_policy(self):
        """Gets the resize_policy of this V1EphemeralContainer.  # noqa: E501

        Resources resize policy for the container.  # noqa: E501

        :return: The resize_policy of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[V1ContainerResizePolicy]
        """
        return self._resize_policy

    @resize_policy.setter
    def resize_policy(self, resize_policy):
        """Sets the resize_policy of this V1EphemeralContainer.

        Resources resize policy for the container.  # noqa: E501

        :param resize_policy: The resize_policy of this V1EphemeralContainer.  # noqa: E501
        :type: list[V1ContainerResizePolicy]
        """

        self._resize_policy = resize_policy

    @property
    def resources(self):
        """Gets the resources of this V1EphemeralContainer.  # noqa: E501


        :return: The resources of this V1EphemeralContainer.  # noqa: E501
        :rtype: V1ResourceRequirements
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this V1EphemeralContainer.


        :param resources: The resources of this V1EphemeralContainer.  # noqa: E501
        :type: V1ResourceRequirements
        """

        self._resources = resources

    @property
    def restart_policy(self):
        """Gets the restart_policy of this V1EphemeralContainer.  # noqa: E501

        Restart policy for the container to manage the restart behavior of each container within a pod. This may only be set for init containers. You cannot set this field on ephemeral containers.  # noqa: E501

        :return: The restart_policy of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._restart_policy

    @restart_policy.setter
    def restart_policy(self, restart_policy):
        """Sets the restart_policy of this V1EphemeralContainer.

        Restart policy for the container to manage the restart behavior of each container within a pod. This may only be set for init containers. You cannot set this field on ephemeral containers.  # noqa: E501

        :param restart_policy: The restart_policy of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """

        self._restart_policy = restart_policy

    @property
    def security_context(self):
        """Gets the security_context of this V1EphemeralContainer.  # noqa: E501


        :return: The security_context of this V1EphemeralContainer.  # noqa: E501
        :rtype: V1SecurityContext
        """
        return self._security_context

    @security_context.setter
    def security_context(self, security_context):
        """Sets the security_context of this V1EphemeralContainer.


        :param security_context: The security_context of this V1EphemeralContainer.  # noqa: E501
        :type: V1SecurityContext
        """

        self._security_context = security_context

    @property
    def startup_probe(self):
        """Gets the startup_probe of this V1EphemeralContainer.  # noqa: E501


        :return: The startup_probe of this V1EphemeralContainer.  # noqa: E501
        :rtype: V1Probe
        """
        return self._startup_probe

    @startup_probe.setter
    def startup_probe(self, startup_probe):
        """Sets the startup_probe of this V1EphemeralContainer.


        :param startup_probe: The startup_probe of this V1EphemeralContainer.  # noqa: E501
        :type: V1Probe
        """

        self._startup_probe = startup_probe

    @property
    def stdin(self):
        """Gets the stdin of this V1EphemeralContainer.  # noqa: E501

        Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.  # noqa: E501

        :return: The stdin of this V1EphemeralContainer.  # noqa: E501
        :rtype: bool
        """
        return self._stdin

    @stdin.setter
    def stdin(self, stdin):
        """Sets the stdin of this V1EphemeralContainer.

        Whether this container should allocate a buffer for stdin in the container runtime. If this is not set, reads from stdin in the container will always result in EOF. Default is false.  # noqa: E501

        :param stdin: The stdin of this V1EphemeralContainer.  # noqa: E501
        :type: bool
        """

        self._stdin = stdin

    @property
    def stdin_once(self):
        """Gets the stdin_once of this V1EphemeralContainer.  # noqa: E501

        Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false  # noqa: E501

        :return: The stdin_once of this V1EphemeralContainer.  # noqa: E501
        :rtype: bool
        """
        return self._stdin_once

    @stdin_once.setter
    def stdin_once(self, stdin_once):
        """Sets the stdin_once of this V1EphemeralContainer.

        Whether the container runtime should close the stdin channel after it has been opened by a single attach. When stdin is true the stdin stream will remain open across multiple attach sessions. If stdinOnce is set to true, stdin is opened on container start, is empty until the first client attaches to stdin, and then remains open and accepts data until the client disconnects, at which time stdin is closed and remains closed until the container is restarted. If this flag is false, a container processes that reads from stdin will never receive an EOF. Default is false  # noqa: E501

        :param stdin_once: The stdin_once of this V1EphemeralContainer.  # noqa: E501
        :type: bool
        """

        self._stdin_once = stdin_once

    @property
    def target_container_name(self):
        """Gets the target_container_name of this V1EphemeralContainer.  # noqa: E501

        If set, the name of the container from PodSpec that this ephemeral container targets. The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container uses the namespaces configured in the Pod spec.  The container runtime must implement support for this feature. If the runtime does not support namespace targeting then the result of setting this field is undefined.  # noqa: E501

        :return: The target_container_name of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._target_container_name

    @target_container_name.setter
    def target_container_name(self, target_container_name):
        """Sets the target_container_name of this V1EphemeralContainer.

        If set, the name of the container from PodSpec that this ephemeral container targets. The ephemeral container will be run in the namespaces (IPC, PID, etc) of this container. If not set then the ephemeral container uses the namespaces configured in the Pod spec.  The container runtime must implement support for this feature. If the runtime does not support namespace targeting then the result of setting this field is undefined.  # noqa: E501

        :param target_container_name: The target_container_name of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """

        self._target_container_name = target_container_name

    @property
    def termination_message_path(self):
        """Gets the termination_message_path of this V1EphemeralContainer.  # noqa: E501

        Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.  # noqa: E501

        :return: The termination_message_path of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._termination_message_path

    @termination_message_path.setter
    def termination_message_path(self, termination_message_path):
        """Sets the termination_message_path of this V1EphemeralContainer.

        Optional: Path at which the file to which the container's termination message will be written is mounted into the container's filesystem. Message written is intended to be brief final status, such as an assertion failure message. Will be truncated by the node if greater than 4096 bytes. The total message length across all containers will be limited to 12kb. Defaults to /dev/termination-log. Cannot be updated.  # noqa: E501

        :param termination_message_path: The termination_message_path of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """

        self._termination_message_path = termination_message_path

    @property
    def termination_message_policy(self):
        """Gets the termination_message_policy of this V1EphemeralContainer.  # noqa: E501

        Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.  # noqa: E501

        :return: The termination_message_policy of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._termination_message_policy

    @termination_message_policy.setter
    def termination_message_policy(self, termination_message_policy):
        """Sets the termination_message_policy of this V1EphemeralContainer.

        Indicate how the termination message should be populated. File will use the contents of terminationMessagePath to populate the container status message on both success and failure. FallbackToLogsOnError will use the last chunk of container log output if the termination message file is empty and the container exited with an error. The log output is limited to 2048 bytes or 80 lines, whichever is smaller. Defaults to File. Cannot be updated.  # noqa: E501

        :param termination_message_policy: The termination_message_policy of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """

        self._termination_message_policy = termination_message_policy

    @property
    def tty(self):
        """Gets the tty of this V1EphemeralContainer.  # noqa: E501

        Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.  # noqa: E501

        :return: The tty of this V1EphemeralContainer.  # noqa: E501
        :rtype: bool
        """
        return self._tty

    @tty.setter
    def tty(self, tty):
        """Sets the tty of this V1EphemeralContainer.

        Whether this container should allocate a TTY for itself, also requires 'stdin' to be true. Default is false.  # noqa: E501

        :param tty: The tty of this V1EphemeralContainer.  # noqa: E501
        :type: bool
        """

        self._tty = tty

    @property
    def volume_devices(self):
        """Gets the volume_devices of this V1EphemeralContainer.  # noqa: E501

        volumeDevices is the list of block devices to be used by the container.  # noqa: E501

        :return: The volume_devices of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[V1VolumeDevice]
        """
        return self._volume_devices

    @volume_devices.setter
    def volume_devices(self, volume_devices):
        """Sets the volume_devices of this V1EphemeralContainer.

        volumeDevices is the list of block devices to be used by the container.  # noqa: E501

        :param volume_devices: The volume_devices of this V1EphemeralContainer.  # noqa: E501
        :type: list[V1VolumeDevice]
        """

        self._volume_devices = volume_devices

    @property
    def volume_mounts(self):
        """Gets the volume_mounts of this V1EphemeralContainer.  # noqa: E501

        Pod volumes to mount into the container's filesystem. Subpath mounts are not allowed for ephemeral containers. Cannot be updated.  # noqa: E501

        :return: The volume_mounts of this V1EphemeralContainer.  # noqa: E501
        :rtype: list[V1VolumeMount]
        """
        return self._volume_mounts

    @volume_mounts.setter
    def volume_mounts(self, volume_mounts):
        """Sets the volume_mounts of this V1EphemeralContainer.

        Pod volumes to mount into the container's filesystem. Subpath mounts are not allowed for ephemeral containers. Cannot be updated.  # noqa: E501

        :param volume_mounts: The volume_mounts of this V1EphemeralContainer.  # noqa: E501
        :type: list[V1VolumeMount]
        """

        self._volume_mounts = volume_mounts

    @property
    def working_dir(self):
        """Gets the working_dir of this V1EphemeralContainer.  # noqa: E501

        Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.  # noqa: E501

        :return: The working_dir of this V1EphemeralContainer.  # noqa: E501
        :rtype: str
        """
        return self._working_dir

    @working_dir.setter
    def working_dir(self, working_dir):
        """Sets the working_dir of this V1EphemeralContainer.

        Container's working directory. If not specified, the container runtime's default will be used, which might be configured in the container image. Cannot be updated.  # noqa: E501

        :param working_dir: The working_dir of this V1EphemeralContainer.  # noqa: E501
        :type: str
        """

        self._working_dir = working_dir

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1EphemeralContainer):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1EphemeralContainer):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "30.1.0b1"

# import apis into sdk package
from kubernetes.client.api.well_known_api import WellKnownApi
from kubernetes.client.api.admissionregistration_api import AdmissionregistrationApi
from kubernetes.client.api.admissionregistration_v1_api import AdmissionregistrationV1Api
from kubernetes.client.api.admissionregistration_v1alpha1_api import AdmissionregistrationV1alpha1Api
from kubernetes.client.api.admissionregistration_v1beta1_api import AdmissionregistrationV1beta1Api
from kubernetes.client.api.apiextensions_api import ApiextensionsApi
from kubernetes.client.api.apiextensions_v1_api import ApiextensionsV1Api
from kubernetes.client.api.apiregistration_api import ApiregistrationApi
from kubernetes.client.api.apiregistration_v1_api import ApiregistrationV1Api
from kubernetes.client.api.apis_api import ApisApi
from kubernetes.client.api.apps_api import AppsApi
from kubernetes.client.api.apps_v1_api import AppsV1Api
from kubernetes.client.api.authentication_api import AuthenticationApi
from kubernetes.client.api.authentication_v1_api import AuthenticationV1Api
from kubernetes.client.api.authentication_v1alpha1_api import AuthenticationV1alpha1Api
from kubernetes.client.api.authentication_v1beta1_api import AuthenticationV1beta1Api
from kubernetes.client.api.authorization_api import AuthorizationApi
from kubernetes.client.api.authorization_v1_api import AuthorizationV1Api
from kubernetes.client.api.autoscaling_api import AutoscalingApi
from kubernetes.client.api.autoscaling_v1_api import AutoscalingV1Api
from kubernetes.client.api.autoscaling_v2_api import AutoscalingV2Api
from kubernetes.client.api.batch_api import BatchApi
from kubernetes.client.api.batch_v1_api import BatchV1Api
from kubernetes.client.api.certificates_api import CertificatesApi
from kubernetes.client.api.certificates_v1_api import CertificatesV1Api
from kubernetes.client.api.certificates_v1alpha1_api import CertificatesV1alpha1Api
from kubernetes.client.api.coordination_api import CoordinationApi
from kubernetes.client.api.coordination_v1_api import CoordinationV1Api
from kubernetes.client.api.core_api import CoreApi
from kubernetes.client.api.core_v1_api import CoreV1Api
from kubernetes.client.api.custom_objects_api import CustomObjectsApi
from kubernetes.client.api.discovery_api import DiscoveryApi
from kubernetes.client.api.discovery_v1_api import DiscoveryV1Api
from kubernetes.client.api.events_api import EventsApi
from kubernetes.client.api.events_v1_api import EventsV1Api
from kubernetes.client.api.flowcontrol_apiserver_api import FlowcontrolApiserverApi
from kubernetes.client.api.flowcontrol_apiserver_v1_api import FlowcontrolApiserverV1Api
from kubernetes.client.api.flowcontrol_apiserver_v1beta3_api import FlowcontrolApiserverV1beta3Api
from kubernetes.client.api.internal_apiserver_api import InternalApiserverApi
from kubernetes.client.api.internal_apiserver_v1alpha1_api import InternalApiserverV1alpha1Api
from kubernetes.client.api.logs_api import LogsApi
from kubernetes.client.api.networking_api import NetworkingApi
from kubernetes.client.api.networking_v1_api import NetworkingV1Api
from kubernetes.client.api.networking_v1alpha1_api import NetworkingV1alpha1Api
from kubernetes.client.api.node_api import NodeApi
from kubernetes.client.api.node_v1_api import NodeV1Api
from kubernetes.client.api.openid_api import OpenidApi
from kubernetes.client.api.policy_api import PolicyApi
from kubernetes.client.api.policy_v1_api import PolicyV1Api
from kubernetes.client.api.rbac_authorization_api import RbacAuthorizationApi
from kubernetes.client.api.rbac_authorization_v1_api import RbacAuthorizationV1Api
from kubernetes.client.api.resource_api import ResourceApi
from kubernetes.client.api.resource_v1alpha2_api import ResourceV1alpha2Api
from kubernetes.client.api.scheduling_api import SchedulingApi
from kubernetes.client.api.scheduling_v1_api import SchedulingV1Api
from kubernetes.client.api.storage_api import StorageApi
from kubernetes.client.api.storage_v1_api import StorageV1Api
from kubernetes.client.api.storage_v1alpha1_api import StorageV1alpha1Api
from kubernetes.client.api.storagemigration_api import StoragemigrationApi
from kubernetes.client.api.storagemigration_v1alpha1_api import StoragemigrationV1alpha1Api
from kubernetes.client.api.version_api import VersionApi

# import ApiClient
from kubernetes.client.api_client import ApiClient
from kubernetes.client.configuration import Configuration
from kubernetes.client.exceptions import OpenApiException
from kubernetes.client.exceptions import ApiTypeError
from kubernetes.client.exceptions import ApiValueError
from kubernetes.client.exceptions import ApiKeyError
from kubernetes.client.exceptions import ApiException
# import models into sdk package
from kubernetes.client.models.admissionregistration_v1_service_reference import AdmissionregistrationV1ServiceReference
from kubernetes.client.models.admissionregistration_v1_webhook_client_config import AdmissionregistrationV1WebhookClientConfig
from kubernetes.client.models.apiextensions_v1_service_reference import ApiextensionsV1ServiceReference
from kubernetes.client.models.apiextensions_v1_webhook_client_config import ApiextensionsV1WebhookClientConfig
from kubernetes.client.models.apiregistration_v1_service_reference import ApiregistrationV1ServiceReference
from kubernetes.client.models.authentication_v1_token_request import AuthenticationV1TokenRequest
from kubernetes.client.models.core_v1_endpoint_port import CoreV1EndpointPort
from kubernetes.client.models.core_v1_event import CoreV1Event
from kubernetes.client.models.core_v1_event_list import CoreV1EventList
from kubernetes.client.models.core_v1_event_series import CoreV1EventSeries
from kubernetes.client.models.discovery_v1_endpoint_port import DiscoveryV1EndpointPort
from kubernetes.client.models.events_v1_event import EventsV1Event
from kubernetes.client.models.events_v1_event_list import EventsV1EventList
from kubernetes.client.models.events_v1_event_series import EventsV1EventSeries
from kubernetes.client.models.flowcontrol_v1_subject import FlowcontrolV1Subject
from kubernetes.client.models.rbac_v1_subject import RbacV1Subject
from kubernetes.client.models.storage_v1_token_request import StorageV1TokenRequest
from kubernetes.client.models.v1_api_group import V1APIGroup
from kubernetes.client.models.v1_api_group_list import V1APIGroupList
from kubernetes.client.models.v1_api_resource import V1APIResource
from kubernetes.client.models.v1_api_resource_list import V1APIResourceList
from kubernetes.client.models.v1_api_service import V1APIService
from kubernetes.client.models.v1_api_service_condition import V1APIServiceCondition
from kubernetes.client.models.v1_api_service_list import V1APIServiceList
from kubernetes.client.models.v1_api_service_spec import V1APIServiceSpec
from kubernetes.client.models.v1_api_service_status import V1APIServiceStatus
from kubernetes.client.models.v1_api_versions import V1APIVersions
from kubernetes.client.models.v1_aws_elastic_block_store_volume_source import V1AWSElasticBlockStoreVolumeSource
from kubernetes.client.models.v1_affinity import V1Affinity
from kubernetes.client.models.v1_aggregation_rule import V1AggregationRule
from kubernetes.client.models.v1_app_armor_profile import V1AppArmorProfile
from kubernetes.client.models.v1_attached_volume import V1AttachedVolume
from kubernetes.client.models.v1_audit_annotation import V1AuditAnnotation
from kubernetes.client.models.v1_azure_disk_volume_source import V1AzureDiskVolumeSource
from kubernetes.client.models.v1_azure_file_persistent_volume_source import V1AzureFilePersistentVolumeSource
from kubernetes.client.models.v1_azure_file_volume_source import V1AzureFileVolumeSource
from kubernetes.client.models.v1_binding import V1Binding
from kubernetes.client.models.v1_bound_object_reference import V1BoundObjectReference
from kubernetes.client.models.v1_csi_driver import V1CSIDriver
from kubernetes.client.models.v1_csi_driver_list import V1CSIDriverList
from kubernetes.client.models.v1_csi_driver_spec import V1CSIDriverSpec
from kubernetes.client.models.v1_csi_node import V1CSINode
from kubernetes.client.models.v1_csi_node_driver import V1CSINodeDriver
from kubernetes.client.models.v1_csi_node_list import V1CSINodeList
from kubernetes.client.models.v1_csi_node_spec import V1CSINodeSpec
from kubernetes.client.models.v1_csi_persistent_volume_source import V1CSIPersistentVolumeSource
from kubernetes.client.models.v1_csi_storage_capacity import V1CSIStorageCapacity
from kubernetes.client.models.v1_csi_storage_capacity_list import V1CSIStorageCapacityList
from kubernetes.client.models.v1_csi_volume_source import V1CSIVolumeSource
from kubernetes.client.models.v1_capabilities import V1Capabilities
from kubernetes.client.models.v1_ceph_fs_persistent_volume_source import V1CephFSPersistentVolumeSource
from kubernetes.client.models.v1_ceph_fs_volume_source import V1CephFSVolumeSource
from kubernetes.client.models.v1_certificate_signing_request import V1CertificateSigningRequest
from kubernetes.client.models.v1_certificate_signing_request_condition import V1CertificateSigningRequestCondition
from kubernetes.client.models.v1_certificate_signing_request_list import V1CertificateSigningRequestList
from kubernetes.client.models.v1_certificate_signing_request_spec import V1CertificateSigningRequestSpec
from kubernetes.client.models.v1_certificate_signing_request_status import V1CertificateSigningRequestStatus
from kubernetes.client.models.v1_cinder_persistent_volume_source import V1CinderPersistentVolumeSource
from kubernetes.client.models.v1_cinder_volume_source import V1CinderVolumeSource
from kubernetes.client.models.v1_claim_source import V1ClaimSource
from kubernetes.client.models.v1_client_ip_config import V1ClientIPConfig
from kubernetes.client.models.v1_cluster_role import V1ClusterRole
from kubernetes.client.models.v1_cluster_role_binding import V1ClusterRoleBinding
from kubernetes.client.models.v1_cluster_role_binding_list import V1ClusterRoleBindingList
from kubernetes.client.models.v1_cluster_role_list import V1ClusterRoleList
from kubernetes.client.models.v1_cluster_trust_bundle_projection import V1ClusterTrustBundleProjection
from kubernetes.client.models.v1_component_condition import V1ComponentCondition
from kubernetes.client.models.v1_component_status import V1ComponentStatus
from kubernetes.client.models.v1_component_status_list import V1ComponentStatusList
from kubernetes.client.models.v1_condition import V1Condition
from kubernetes.client.models.v1_config_map import V1ConfigMap
from kubernetes.client.models.v1_config_map_env_source import V1ConfigMapEnvSource
from kubernetes.client.models.v1_config_map_key_selector import V1ConfigMapKeySelector
from kubernetes.client.models.v1_config_map_list import V1ConfigMapList
from kubernetes.client.models.v1_config_map_node_config_source import V1ConfigMapNodeConfigSource
from kubernetes.client.models.v1_config_map_projection import V1ConfigMapProjection
from kubernetes.client.models.v1_config_map_volume_source import V1ConfigMapVolumeSource
from kubernetes.client.models.v1_container import V1Container
from kubernetes.client.models.v1_container_image import V1ContainerImage
from kubernetes.client.models.v1_container_port import V1ContainerPort
from kubernetes.client.models.v1_container_resize_policy import V1ContainerResizePolicy
from kubernetes.client.models.v1_container_state import V1ContainerState
from kubernetes.client.models.v1_container_state_running import V1ContainerStateRunning
from kubernetes.client.models.v1_container_state_terminated import V1ContainerStateTerminated
from kubernetes.client.models.v1_container_state_waiting import V1ContainerStateWaiting
from kubernetes.client.models.v1_container_status import V1ContainerStatus
from kubernetes.client.models.v1_controller_revision import V1ControllerRevision
from kubernetes.client.models.v1_controller_revision_list import V1ControllerRevisionList
from kubernetes.client.models.v1_cron_job import V1CronJob
from kubernetes.client.models.v1_cron_job_list import V1CronJobList
from kubernetes.client.models.v1_cron_job_spec import V1CronJobSpec
from kubernetes.client.models.v1_cron_job_status import V1CronJobStatus
from kubernetes.client.models.v1_cross_version_object_reference import V1CrossVersionObjectReference
from kubernetes.client.models.v1_custom_resource_column_definition import V1CustomResourceColumnDefinition
from kubernetes.client.models.v1_custom_resource_conversion import V1CustomResourceConversion
from kubernetes.client.models.v1_custom_resource_definition import V1CustomResourceDefinition
from kubernetes.client.models.v1_custom_resource_definition_condition import V1CustomResourceDefinitionCondition
from kubernetes.client.models.v1_custom_resource_definition_list import V1CustomResourceDefinitionList
from kubernetes.client.models.v1_custom_resource_definition_names import V1CustomResourceDefinitionNames
from kubernetes.client.models.v1_custom_resource_definition_spec import V1CustomResourceDefinitionSpec
from kubernetes.client.models.v1_custom_resource_definition_status import V1CustomResourceDefinitionStatus
from kubernetes.client.models.v1_custom_resource_definition_version import V1CustomResourceDefinitionVersion
from kubernetes.client.models.v1_custom_resource_subresource_scale import V1CustomResourceSubresourceScale
from kubernetes.client.models.v1_custom_resource_subresources import V1CustomResourceSubresources
from kubernetes.client.models.v1_custom_resource_validation import V1CustomResourceValidation
from kubernetes.client.models.v1_daemon_endpoint import V1DaemonEndpoint
from kubernetes.client.models.v1_daemon_set import V1DaemonSet
from kubernetes.client.models.v1_daemon_set_condition import V1DaemonSetCondition
from kubernetes.client.models.v1_daemon_set_list import V1DaemonSetList
from kubernetes.client.models.v1_daemon_set_spec import V1DaemonSetSpec
from kubernetes.client.models.v1_daemon_set_status import V1DaemonSetStatus
from kubernetes.client.models.v1_daemon_set_update_strategy import V1DaemonSetUpdateStrategy
from kubernetes.client.models.v1_delete_options import V1DeleteOptions
from kubernetes.client.models.v1_deployment import V1Deployment
from kubernetes.client.models.v1_deployment_condition import V1DeploymentCondition
from kubernetes.client.models.v1_deployment_list import V1DeploymentList
from kubernetes.client.models.v1_deployment_spec import V1DeploymentSpec
from kubernetes.client.models.v1_deployment_status import V1DeploymentStatus
from kubernetes.client.models.v1_deployment_strategy import V1DeploymentStrategy
from kubernetes.client.models.v1_downward_api_projection import V1DownwardAPIProjection
from kubernetes.client.models.v1_downward_api_volume_file import V1DownwardAPIVolumeFile
from kubernetes.client.models.v1_downward_api_volume_source import V1DownwardAPIVolumeSource
from kubernetes.client.models.v1_empty_dir_volume_source import V1EmptyDirVolumeSource
from kubernetes.client.models.v1_endpoint import V1Endpoint
from kubernetes.client.models.v1_endpoint_address import V1EndpointAddress
from kubernetes.client.models.v1_endpoint_conditions import V1EndpointConditions
from kubernetes.client.models.v1_endpoint_hints import V1EndpointHints
from kubernetes.client.models.v1_endpoint_slice import V1EndpointSlice
from kubernetes.client.models.v1_endpoint_slice_list import V1EndpointSliceList
from kubernetes.client.models.v1_endpoint_subset import V1EndpointSubset
from kubernetes.client.models.v1_endpoints import V1Endpoints
from kubernetes.client.models.v1_endpoints_list import V1EndpointsList
from kubernetes.client.models.v1_env_from_source import V1EnvFromSource
from kubernetes.client.models.v1_env_var import V1EnvVar
from kubernetes.client.models.v1_env_var_source import V1EnvVarSource
from kubernetes.client.models.v1_ephemeral_container import V1EphemeralContainer
from kubernetes.client.models.v1_ephemeral_volume_source import V1EphemeralVolumeSource
from kubernetes.client.models.v1_event_source import V1EventSource
from kubernetes.client.models.v1_eviction import V1Eviction
from kubernetes.client.models.v1_exec_action import V1ExecAction
from kubernetes.client.models.v1_exempt_priority_level_configuration import V1ExemptPriorityLevelConfiguration
from kubernetes.client.models.v1_expression_warning import V1ExpressionWarning
from kubernetes.client.models.v1_external_documentation import V1ExternalDocumentation
from kubernetes.client.models.v1_fc_volume_source import V1FCVolumeSource
from kubernetes.client.models.v1_flex_persistent_volume_source import V1FlexPersistentVolumeSource
from kubernetes.client.models.v1_flex_volume_source import V1FlexVolumeSource
from kubernetes.client.models.v1_flocker_volume_source import V1FlockerVolumeSource
from kubernetes.client.models.v1_flow_distinguisher_method import V1FlowDistinguisherMethod
from kubernetes.client.models.v1_flow_schema import V1FlowSchema
from kubernetes.client.models.v1_flow_schema_condition import V1FlowSchemaCondition
from kubernetes.client.models.v1_flow_schema_list import V1FlowSchemaList
from kubernetes.client.models.v1_flow_schema_spec import V1FlowSchemaSpec
from kubernetes.client.models.v1_flow_schema_status import V1FlowSchemaStatus
from kubernetes.client.models.v1_for_zone import V1ForZone
from kubernetes.client.models.v1_gce_persistent_disk_volume_source import V1GCEPersistentDiskVolumeSource
from kubernetes.client.models.v1_grpc_action import V1GRPCAction
from kubernetes.client.models.v1_git_repo_volume_source import V1GitRepoVolumeSource
from kubernetes.client.models.v1_glusterfs_persistent_volume_source import V1GlusterfsPersistentVolumeSource
from kubernetes.client.models.v1_glusterfs_volume_source import V1GlusterfsVolumeSource
from kubernetes.client.models.v1_group_subject import V1GroupSubject
from kubernetes.client.models.v1_group_version_for_discovery import V1GroupVersionForDiscovery
from kubernetes.client.models.v1_http_get_action import V1HTTPGetAction
from kubernetes.client.models.v1_http_header import V1HTTPHeader
from kubernetes.client.models.v1_http_ingress_path import V1HTTPIngressPath
from kubernetes.client.models.v1_http_ingress_rule_value import V1HTTPIngressRuleValue
from kubernetes.client.models.v1_horizontal_pod_autoscaler import V1HorizontalPodAutoscaler
from kubernetes.client.models.v1_horizontal_pod_autoscaler_list import V1HorizontalPodAutoscalerList
from kubernetes.client.models.v1_horizontal_pod_autoscaler_spec import V1HorizontalPodAutoscalerSpec
from kubernetes.client.models.v1_horizontal_pod_autoscaler_status import V1HorizontalPodAutoscalerStatus
from kubernetes.client.models.v1_host_alias import V1HostAlias
from kubernetes.client.models.v1_host_ip import V1HostIP
from kubernetes.client.models.v1_host_path_volume_source import V1HostPathVolumeSource
from kubernetes.client.models.v1_ip_block import V1IPBlock
from kubernetes.client.models.v1_iscsi_persistent_volume_source import V1ISCSIPersistentVolumeSource
from kubernetes.client.models.v1_iscsi_volume_source import V1ISCSIVolumeSource
from kubernetes.client.models.v1_ingress import V1Ingress
from kubernetes.client.models.v1_ingress_backend import V1IngressBackend
from kubernetes.client.models.v1_ingress_class import V1IngressClass
from kubernetes.client.models.v1_ingress_class_list import V1IngressClassList
from kubernetes.client.models.v1_ingress_class_parameters_reference import V1IngressClassParametersReference
from kubernetes.client.models.v1_ingress_class_spec import V1IngressClassSpec
from kubernetes.client.models.v1_ingress_list import V1IngressList
from kubernetes.client.models.v1_ingress_load_balancer_ingress import V1IngressLoadBalancerIngress
from kubernetes.client.models.v1_ingress_load_balancer_status import V1IngressLoadBalancerStatus
from kubernetes.client.models.v1_ingress_port_status import V1IngressPortStatus
from kubernetes.client.models.v1_ingress_rule import V1IngressRule
from kubernetes.client.models.v1_ingress_service_backend import V1IngressServiceBackend
from kubernetes.client.models.v1_ingress_spec import V1IngressSpec
from kubernetes.client.models.v1_ingress_status import V1IngressStatus
from kubernetes.client.models.v1_ingress_tls import V1IngressTLS
from kubernetes.client.models.v1_json_schema_props import V1JSONSchemaProps
from kubernetes.client.models.v1_job import V1Job
from kubernetes.client.models.v1_job_condition import V1JobCondition
from kubernetes.client.models.v1_job_list import V1JobList
from kubernetes.client.models.v1_job_spec import V1JobSpec
from kubernetes.client.models.v1_job_status import V1JobStatus
from kubernetes.client.models.v1_job_template_spec import V1JobTemplateSpec
from kubernetes.client.models.v1_key_to_path import V1KeyToPath
from kubernetes.client.models.v1_label_selector import V1LabelSelector
from kubernetes.client.models.v1_label_selector_requirement import V1LabelSelectorRequirement
from kubernetes.client.models.v1_lease import V1Lease
from kubernetes.client.models.v1_lease_list import V1LeaseList
from kubernetes.client.models.v1_lease_spec import V1LeaseSpec
from kubernetes.client.models.v1_lifecycle import V1Lifecycle
from kubernetes.client.models.v1_lifecycle_handler import V1LifecycleHandler
from kubernetes.client.models.v1_limit_range import V1LimitRange
from kubernetes.client.models.v1_limit_range_item import V1LimitRangeItem
from kubernetes.client.models.v1_limit_range_list import V1LimitRangeList
from kubernetes.client.models.v1_limit_range_spec import V1LimitRangeSpec
from kubernetes.client.models.v1_limit_response import V1LimitResponse
from kubernetes.client.models.v1_limited_priority_level_configuration import V1LimitedPriorityLevelConfiguration
from kubernetes.client.models.v1_list_meta import V1ListMeta
from kubernetes.client.models.v1_load_balancer_ingress import V1LoadBalancerIngress
from kubernetes.client.models.v1_load_balancer_status import V1LoadBalancerStatus
from kubernetes.client.models.v1_local_object_reference import V1LocalObjectReference
from kubernetes.client.models.v1_local_subject_access_review import V1LocalSubjectAccessReview
from kubernetes.client.models.v1_local_volume_source import V1LocalVolumeSource
from kubernetes.client.models.v1_managed_fields_entry import V1ManagedFieldsEntry
from kubernetes.client.models.v1_match_condition import V1MatchCondition
from kubernetes.client.models.v1_match_resources import V1MatchResources
from kubernetes.client.models.v1_modify_volume_status import V1ModifyVolumeStatus
from kubernetes.client.models.v1_mutating_webhook import V1MutatingWebhook
from kubernetes.client.models.v1_mutating_webhook_configuration import V1MutatingWebhookConfiguration
from kubernetes.client.models.v1_mutating_webhook_configuration_list import V1MutatingWebhookConfigurationList
from kubernetes.client.models.v1_nfs_volume_source import V1NFSVolumeSource
from kubernetes.client.models.v1_named_rule_with_operations import V1NamedRuleWithOperations
from kubernetes.client.models.v1_namespace import V1Namespace
from kubernetes.client.models.v1_namespace_condition import V1NamespaceCondition
from kubernetes.client.models.v1_namespace_list import V1NamespaceList
from kubernetes.client.models.v1_namespace_spec import V1NamespaceSpec
from kubernetes.client.models.v1_namespace_status import V1NamespaceStatus
from kubernetes.client.models.v1_network_policy import V1NetworkPolicy
from kubernetes.client.models.v1_network_policy_egress_rule import V1NetworkPolicyEgressRule
from kubernetes.client.models.v1_network_policy_ingress_rule import V1NetworkPolicyIngressRule
from kubernetes.client.models.v1_network_policy_list import V1NetworkPolicyList
from kubernetes.client.models.v1_network_policy_peer import V1NetworkPolicyPeer
from kubernetes.client.models.v1_network_policy_port import V1NetworkPolicyPort
from kubernetes.client.models.v1_network_policy_spec import V1NetworkPolicySpec
from kubernetes.client.models.v1_node import V1Node
from kubernetes.client.models.v1_node_address import V1NodeAddress
from kubernetes.client.models.v1_node_affinity import V1NodeAffinity
from kubernetes.client.models.v1_node_condition import V1NodeCondition
from kubernetes.client.models.v1_node_config_source import V1NodeConfigSource
from kubernetes.client.models.v1_node_config_status import V1NodeConfigStatus
from kubernetes.client.models.v1_node_daemon_endpoints import V1NodeDaemonEndpoints
from kubernetes.client.models.v1_node_list import V1NodeList
from kubernetes.client.models.v1_node_runtime_handler import V1NodeRuntimeHandler
from kubernetes.client.models.v1_node_runtime_handler_features import V1NodeRuntimeHandlerFeatures
from kubernetes.client.models.v1_node_selector import V1NodeSelector
from kubernetes.client.models.v1_node_selector_requirement import V1NodeSelectorRequirement
from kubernetes.client.models.v1_node_selector_term import V1NodeSelectorTerm
from kubernetes.client.models.v1_node_spec import V1NodeSpec
from kubernetes.client.models.v1_node_status import V1NodeStatus
from kubernetes.client.models.v1_node_system_info import V1NodeSystemInfo
from kubernetes.client.models.v1_non_resource_attributes import V1NonResourceAttributes
from kubernetes.client.models.v1_non_resource_policy_rule import V1NonResourcePolicyRule
from kubernetes.client.models.v1_non_resource_rule import V1NonResourceRule
from kubernetes.client.models.v1_object_field_selector import V1ObjectFieldSelector
from kubernetes.client.models.v1_object_meta import V1ObjectMeta
from kubernetes.client.models.v1_object_reference import V1ObjectReference
from kubernetes.client.models.v1_overhead import V1Overhead
from kubernetes.client.models.v1_owner_reference import V1OwnerReference
from kubernetes.client.models.v1_param_kind import V1ParamKind
from kubernetes.client.models.v1_param_ref import V1ParamRef
from kubernetes.client.models.v1_persistent_volume import V1PersistentVolume
from kubernetes.client.models.v1_persistent_volume_claim import V1PersistentVolumeClaim
from kubernetes.client.models.v1_persistent_volume_claim_condition import V1PersistentVolumeClaimCondition
from kubernetes.client.models.v1_persistent_volume_claim_list import V1PersistentVolumeClaimList
from kubernetes.client.models.v1_persistent_volume_claim_spec import V1PersistentVolumeClaimSpec
from kubernetes.client.models.v1_persistent_volume_claim_status import V1PersistentVolumeClaimStatus
from kubernetes.client.models.v1_persistent_volume_claim_template import V1PersistentVolumeClaimTemplate
from kubernetes.client.models.v1_persistent_volume_claim_volume_source import V1PersistentVolumeClaimVolumeSource
from kubernetes.client.models.v1_persistent_volume_list import V1PersistentVolumeList
from kubernetes.client.models.v1_persistent_volume_spec import V1PersistentVolumeSpec
from kubernetes.client.models.v1_persistent_volume_status import V1PersistentVolumeStatus
from kubernetes.client.models.v1_photon_persistent_disk_volume_source import V1PhotonPersistentDiskVolumeSource
from kubernetes.client.models.v1_pod import V1Pod
from kubernetes.client.models.v1_pod_affinity import V1PodAffinity
from kubernetes.client.models.v1_pod_affinity_term import V1PodAffinityTerm
from kubernetes.client.models.v1_pod_anti_affinity import V1PodAntiAffinity
from kubernetes.client.models.v1_pod_condition import V1PodCondition
from kubernetes.client.models.v1_pod_dns_config import V1PodDNSConfig
from kubernetes.client.models.v1_pod_dns_config_option import V1PodDNSConfigOption
from kubernetes.client.models.v1_pod_disruption_budget import V1PodDisruptionBudget
from kubernetes.client.models.v1_pod_disruption_budget_list import V1PodDisruptionBudgetList
from kubernetes.client.models.v1_pod_disruption_budget_spec import V1PodDisruptionBudgetSpec
from kubernetes.client.models.v1_pod_disruption_budget_status import V1PodDisruptionBudgetStatus
from kubernetes.client.models.v1_pod_failure_policy import V1PodFailurePolicy
from kubernetes.client.models.v1_pod_failure_policy_on_exit_codes_requirement import V1PodFailurePolicyOnExitCodesRequirement
from kubernetes.client.models.v1_pod_failure_policy_on_pod_conditions_pattern import V1PodFailurePolicyOnPodConditionsPattern
from kubernetes.client.models.v1_pod_failure_policy_rule import V1PodFailurePolicyRule
from kubernetes.client.models.v1_pod_ip import V1PodIP
from kubernetes.client.models.v1_pod_list import V1PodList
from kubernetes.client.models.v1_pod_os import V1PodOS
from kubernetes.client.models.v1_pod_readiness_gate import V1PodReadinessGate
from kubernetes.client.models.v1_pod_resource_claim import V1PodResourceClaim
from kubernetes.client.models.v1_pod_resource_claim_status import V1PodResourceClaimStatus
from kubernetes.client.models.v1_pod_scheduling_gate import V1PodSchedulingGate
from kubernetes.client.models.v1_pod_security_context import V1PodSecurityContext
from kubernetes.client.models.v1_pod_spec import V1PodSpec
from kubernetes.client.models.v1_pod_status import V1PodStatus
from kubernetes.client.models.v1_pod_template import V1PodTemplate
from kubernetes.client.models.v1_pod_template_list import V1PodTemplateList
from kubernetes.client.models.v1_pod_template_spec import V1PodTemplateSpec
from kubernetes.client.models.v1_policy_rule import V1PolicyRule
from kubernetes.client.models.v1_policy_rules_with_subjects import V1PolicyRulesWithSubjects
from kubernetes.client.models.v1_port_status import V1PortStatus
from kubernetes.client.models.v1_portworx_volume_source import V1PortworxVolumeSource
from kubernetes.client.models.v1_preconditions import V1Preconditions
from kubernetes.client.models.v1_preferred_scheduling_term import V1PreferredSchedulingTerm
from kubernetes.client.models.v1_priority_class import V1PriorityClass
from kubernetes.client.models.v1_priority_class_list import V1PriorityClassList
from kubernetes.client.models.v1_priority_level_configuration import V1PriorityLevelConfiguration
from kubernetes.client.models.v1_priority_level_configuration_condition import V1PriorityLevelConfigurationCondition
from kubernetes.client.models.v1_priority_level_configuration_list import V1PriorityLevelConfigurationList
from kubernetes.client.models.v1_priority_level_configuration_reference import V1PriorityLevelConfigurationReference
from kubernetes.client.models.v1_priority_level_configuration_spec import V1PriorityLevelConfigurationSpec
from kubernetes.client.models.v1_priority_level_configuration_status import V1PriorityLevelConfigurationStatus
from kubernetes.client.models.v1_probe import V1Probe
from kubernetes.client.models.v1_projected_volume_source import V1ProjectedVolumeSource
from kubernetes.client.models.v1_queuing_configuration import V1QueuingConfiguration
from kubernetes.client.models.v1_quobyte_volume_source import V1QuobyteVolumeSource
from kubernetes.client.models.v1_rbd_persistent_volume_source import V1RBDPersistentVolumeSource
from kubernetes.client.models.v1_rbd_volume_source import V1RBDVolumeSource
from kubernetes.client.models.v1_replica_set import V1ReplicaSet
from kubernetes.client.models.v1_replica_set_condition import V1ReplicaSetCondition
from kubernetes.client.models.v1_replica_set_list import V1ReplicaSetList
from kubernetes.client.models.v1_replica_set_spec import V1ReplicaSetSpec
from kubernetes.client.models.v1_replica_set_status import V1ReplicaSetStatus
from kubernetes.client.models.v1_replication_controller import V1ReplicationController
from kubernetes.client.models.v1_replication_controller_condition import V1ReplicationControllerCondition
from kubernetes.client.models.v1_replication_controller_list import V1ReplicationControllerList
from kubernetes.client.models.v1_replication_controller_spec import V1ReplicationControllerSpec
from kubernetes.client.models.v1_replication_controller_status import V1ReplicationControllerStatus
from kubernetes.client.models.v1_resource_attributes import V1ResourceAttributes
from kubernetes.client.models.v1_resource_claim import V1ResourceClaim
from kubernetes.client.models.v1_resource_field_selector import V1ResourceFieldSelector
from kubernetes.client.models.v1_resource_policy_rule import V1ResourcePolicyRule
from kubernetes.client.models.v1_resource_quota import V1ResourceQuota
from kubernetes.client.models.v1_resource_quota_list import V1ResourceQuotaList
from kubernetes.client.models.v1_resource_quota_spec import V1ResourceQuotaSpec
from kubernetes.client.models.v1_resource_quota_status import V1ResourceQuotaStatus
from kubernetes.client.models.v1_resource_requirements import V1ResourceRequirements
from kubernetes.client.models.v1_resource_rule import V1ResourceRule
from kubernetes.client.models.v1_role import V1Role
from kubernetes.client.models.v1_role_binding import V1RoleBinding
from kubernetes.client.models.v1_role_binding_list import V1RoleBindingList
from kubernetes.client.models.v1_role_list import V1RoleList
from kubernetes.client.models.v1_role_ref import V1RoleRef
from kubernetes.client.models.v1_rolling_update_daemon_set import V1RollingUpdateDaemonSet
from kubernetes.client.models.v1_rolling_update_deployment import V1RollingUpdateDeployment
from kubernetes.client.models.v1_rolling_update_stateful_set_strategy import V1RollingUpdateStatefulSetStrategy
from kubernetes.client.models.v1_rule_with_operations import V1RuleWithOperations
from kubernetes.client.models.v1_runtime_class import V1RuntimeClass
from kubernetes.client.models.v1_runtime_class_list import V1RuntimeClassList
from kubernetes.client.models.v1_se_linux_options import V1SELinuxOptions
from kubernetes.client.models.v1_scale import V1Scale
from kubernetes.client.models.v1_scale_io_persistent_volume_source import V1ScaleIOPersistentVolumeSource
from kubernetes.client.models.v1_scale_io_volume_source import V1ScaleIOVolumeSource
from kubernetes.client.models.v1_scale_spec import V1ScaleSpec
from kubernetes.client.models.v1_scale_status import V1ScaleStatus
from kubernetes.client.models.v1_scheduling import V1Scheduling
from kubernetes.client.models.v1_scope_selector import V1ScopeSelector
from kubernetes.client.models.v1_scoped_resource_selector_requirement import V1ScopedResourceSelectorRequirement
from kubernetes.client.models.v1_seccomp_profile import V1SeccompProfile
from kubernetes.client.models.v1_secret import V1Secret
from kubernetes.client.models.v1_secret_env_source import V1SecretEnvSource
from kubernetes.client.models.v1_secret_key_selector import V1SecretKeySelector
from kubernetes.client.models.v1_secret_list import V1SecretList
from kubernetes.client.models.v1_secret_projection import V1SecretProjection
from kubernetes.client.models.v1_secret_reference import V1SecretReference
from kubernetes.client.models.v1_secret_volume_source import V1SecretVolumeSource
from kubernetes.client.models.v1_security_context import V1SecurityContext
from kubernetes.client.models.v1_selectable_field import V1SelectableField
from kubernetes.client.models.v1_self_subject_access_review import V1SelfSubjectAccessReview
from kubernetes.client.models.v1_self_subject_access_review_spec import V1SelfSubjectAccessReviewSpec
from kubernetes.client.models.v1_self_subject_review import V1SelfSubjectReview
from kubernetes.client.models.v1_self_subject_review_status import V1SelfSubjectReviewStatus
from kubernetes.client.models.v1_self_subject_rules_review import V1SelfSubjectRulesReview
from kubernetes.client.models.v1_self_subject_rules_review_spec import V1SelfSubjectRulesReviewSpec
from kubernetes.client.models.v1_server_address_by_client_cidr import V1ServerAddressByClientCIDR
from kubernetes.client.models.v1_service import V1Service
from kubernetes.client.models.v1_service_account import V1ServiceAccount
from kubernetes.client.models.v1_service_account_list import V1ServiceAccountList
from kubernetes.client.models.v1_service_account_subject import V1ServiceAccountSubject
from kubernetes.client.models.v1_service_account_token_projection import V1ServiceAccountTokenProjection
from kubernetes.client.models.v1_service_backend_port import V1ServiceBackendPort
from kubernetes.client.models.v1_service_list import V1ServiceList
from kubernetes.client.models.v1_service_port import V1ServicePort
from kubernetes.client.models.v1_service_spec import V1ServiceSpec
from kubernetes.client.models.v1_service_status import V1ServiceStatus
from kubernetes.client.models.v1_session_affinity_config import V1SessionAffinityConfig
from kubernetes.client.models.v1_sleep_action import V1SleepAction
from kubernetes.client.models.v1_stateful_set import V1StatefulSet
from kubernetes.client.models.v1_stateful_set_condition import V1StatefulSetCondition
from kubernetes.client.models.v1_stateful_set_list import V1StatefulSetList
from kubernetes.client.models.v1_stateful_set_ordinals import V1StatefulSetOrdinals
from kubernetes.client.models.v1_stateful_set_persistent_volume_claim_retention_policy import V1StatefulSetPersistentVolumeClaimRetentionPolicy
from kubernetes.client.models.v1_stateful_set_spec import V1StatefulSetSpec
from kubernetes.client.models.v1_stateful_set_status import V1StatefulSetStatus
from kubernetes.client.models.v1_stateful_set_update_strategy import V1StatefulSetUpdateStrategy
from kubernetes.client.models.v1_status import V1Status
from kubernetes.client.models.v1_status_cause import V1StatusCause
from kubernetes.client.models.v1_status_details import V1StatusDetails
from kubernetes.client.models.v1_storage_class import V1StorageClass
from kubernetes.client.models.v1_storage_class_list import V1StorageClassList
from kubernetes.client.models.v1_storage_os_persistent_volume_source import V1StorageOSPersistentVolumeSource
from kubernetes.client.models.v1_storage_os_volume_source import V1StorageOSVolumeSource
from kubernetes.client.models.v1_subject_access_review import V1SubjectAccessReview
from kubernetes.client.models.v1_subject_access_review_spec import V1SubjectAccessReviewSpec
from kubernetes.client.models.v1_subject_access_review_status import V1SubjectAccessReviewStatus
from kubernetes.client.models.v1_subject_rules_review_status import V1SubjectRulesReviewStatus
from kubernetes.client.models.v1_success_policy import V1SuccessPolicy
from kubernetes.client.models.v1_success_policy_rule import V1SuccessPolicyRule
from kubernetes.client.models.v1_sysctl import V1Sysctl
from kubernetes.client.models.v1_tcp_socket_action import V1TCPSocketAction
from kubernetes.client.models.v1_taint import V1Taint
from kubernetes.client.models.v1_token_request_spec import V1TokenRequestSpec
from kubernetes.client.models.v1_token_request_status import V1TokenRequestStatus
from kubernetes.client.models.v1_token_review import V1TokenReview
from kubernetes.client.models.v1_token_review_spec import V1TokenReviewSpec
from kubernetes.client.models.v1_token_review_status import V1TokenReviewStatus
from kubernetes.client.models.v1_toleration import V1Toleration
from kubernetes.client.models.v1_topology_selector_label_requirement import V1TopologySelectorLabelRequirement
from kubernetes.client.models.v1_topology_selector_term import V1TopologySelectorTerm
from kubernetes.client.models.v1_topology_spread_constraint import V1TopologySpreadConstraint
from kubernetes.client.models.v1_type_checking import V1TypeChecking
from kubernetes.client.models.v1_typed_local_object_reference import V1TypedLocalObjectReference
from kubernetes.client.models.v1_typed_object_reference import V1TypedObjectReference
from kubernetes.client.models.v1_uncounted_terminated_pods import V1UncountedTerminatedPods
from kubernetes.client.models.v1_user_info import V1UserInfo
from kubernetes.client.models.v1_user_subject import V1UserSubject
from kubernetes.client.models.v1_validating_admission_policy import V1ValidatingAdmissionPolicy
from kubernetes.client.models.v1_validating_admission_policy_binding import V1ValidatingAdmissionPolicyBinding
from kubernetes.client.models.v1_validating_admission_policy_binding_list import V1ValidatingAdmissionPolicyBindingList
from kubernetes.client.models.v1_validating_admission_policy_binding_spec import V1ValidatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1_validating_admission_policy_list import V1ValidatingAdmissionPolicyList
from kubernetes.client.models.v1_validating_admission_policy_spec import V1ValidatingAdmissionPolicySpec
from kubernetes.client.models.v1_validating_admission_policy_status import V1ValidatingAdmissionPolicyStatus
from kubernetes.client.models.v1_validating_webhook import V1ValidatingWebhook
from kubernetes.client.models.v1_validating_webhook_configuration import V1ValidatingWebhookConfiguration
from kubernetes.client.models.v1_validating_webhook_configuration_list import V1ValidatingWebhookConfigurationList
from kubernetes.client.models.v1_validation import V1Validation
from kubernetes.client.models.v1_validation_rule import V1ValidationRule
from kubernetes.client.models.v1_variable import V1Variable
from kubernetes.client.models.v1_volume import V1Volume
from kubernetes.client.models.v1_volume_attachment import V1VolumeAttachment
from kubernetes.client.models.v1_volume_attachment_list import V1VolumeAttachmentList
from kubernetes.client.models.v1_volume_attachment_source import V1VolumeAttachmentSource
from kubernetes.client.models.v1_volume_attachment_spec import V1VolumeAttachmentSpec
from kubernetes.client.models.v1_volume_attachment_status import V1VolumeAttachmentStatus
from kubernetes.client.models.v1_volume_device import V1VolumeDevice
from kubernetes.client.models.v1_volume_error import V1VolumeError
from kubernetes.client.models.v1_volume_mount import V1VolumeMount
from kubernetes.client.models.v1_volume_mount_status import V1VolumeMountStatus
from kubernetes.client.models.v1_volume_node_affinity import V1VolumeNodeAffinity
from kubernetes.client.models.v1_volume_node_resources import V1VolumeNodeResources
from kubernetes.client.models.v1_volume_projection import V1VolumeProjection
from kubernetes.client.models.v1_volume_resource_requirements import V1VolumeResourceRequirements
from kubernetes.client.models.v1_vsphere_virtual_disk_volume_source import V1VsphereVirtualDiskVolumeSource
from kubernetes.client.models.v1_watch_event import V1WatchEvent
from kubernetes.client.models.v1_webhook_conversion import V1WebhookConversion
from kubernetes.client.models.v1_weighted_pod_affinity_term import V1WeightedPodAffinityTerm
from kubernetes.client.models.v1_windows_security_context_options import V1WindowsSecurityContextOptions
from kubernetes.client.models.v1alpha1_audit_annotation import V1alpha1AuditAnnotation
from kubernetes.client.models.v1alpha1_cluster_trust_bundle import V1alpha1ClusterTrustBundle
from kubernetes.client.models.v1alpha1_cluster_trust_bundle_list import V1alpha1ClusterTrustBundleList
from kubernetes.client.models.v1alpha1_cluster_trust_bundle_spec import V1alpha1ClusterTrustBundleSpec
from kubernetes.client.models.v1alpha1_expression_warning import V1alpha1ExpressionWarning
from kubernetes.client.models.v1alpha1_group_version_resource import V1alpha1GroupVersionResource
from kubernetes.client.models.v1alpha1_ip_address import V1alpha1IPAddress
from kubernetes.client.models.v1alpha1_ip_address_list import V1alpha1IPAddressList
from kubernetes.client.models.v1alpha1_ip_address_spec import V1alpha1IPAddressSpec
from kubernetes.client.models.v1alpha1_match_condition import V1alpha1MatchCondition
from kubernetes.client.models.v1alpha1_match_resources import V1alpha1MatchResources
from kubernetes.client.models.v1alpha1_migration_condition import V1alpha1MigrationCondition
from kubernetes.client.models.v1alpha1_named_rule_with_operations import V1alpha1NamedRuleWithOperations
from kubernetes.client.models.v1alpha1_param_kind import V1alpha1ParamKind
from kubernetes.client.models.v1alpha1_param_ref import V1alpha1ParamRef
from kubernetes.client.models.v1alpha1_parent_reference import V1alpha1ParentReference
from kubernetes.client.models.v1alpha1_self_subject_review import V1alpha1SelfSubjectReview
from kubernetes.client.models.v1alpha1_self_subject_review_status import V1alpha1SelfSubjectReviewStatus
from kubernetes.client.models.v1alpha1_server_storage_version import V1alpha1ServerStorageVersion
from kubernetes.client.models.v1alpha1_service_cidr import V1alpha1ServiceCIDR
from kubernetes.client.models.v1alpha1_service_cidr_list import V1alpha1ServiceCIDRList
from kubernetes.client.models.v1alpha1_service_cidr_spec import V1alpha1ServiceCIDRSpec
from kubernetes.client.models.v1alpha1_service_cidr_status import V1alpha1ServiceCIDRStatus
from kubernetes.client.models.v1alpha1_storage_version import V1alpha1StorageVersion
from kubernetes.client.models.v1alpha1_storage_version_condition import V1alpha1StorageVersionCondition
from kubernetes.client.models.v1alpha1_storage_version_list import V1alpha1StorageVersionList
from kubernetes.client.models.v1alpha1_storage_version_migration import V1alpha1StorageVersionMigration
from kubernetes.client.models.v1alpha1_storage_version_migration_list import V1alpha1StorageVersionMigrationList
from kubernetes.client.models.v1alpha1_storage_version_migration_spec import V1alpha1StorageVersionMigrationSpec
from kubernetes.client.models.v1alpha1_storage_version_migration_status import V1alpha1StorageVersionMigrationStatus
from kubernetes.client.models.v1alpha1_storage_version_status import V1alpha1StorageVersionStatus
from kubernetes.client.models.v1alpha1_type_checking import V1alpha1TypeChecking
from kubernetes.client.models.v1alpha1_validating_admission_policy import V1alpha1ValidatingAdmissionPolicy
from kubernetes.client.models.v1alpha1_validating_admission_policy_binding import V1alpha1ValidatingAdmissionPolicyBinding
from kubernetes.client.models.v1alpha1_validating_admission_policy_binding_list import V1alpha1ValidatingAdmissionPolicyBindingList
from kubernetes.client.models.v1alpha1_validating_admission_policy_binding_spec import V1alpha1ValidatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1alpha1_validating_admission_policy_list import V1alpha1ValidatingAdmissionPolicyList
from kubernetes.client.models.v1alpha1_validating_admission_policy_spec import V1alpha1ValidatingAdmissionPolicySpec
from kubernetes.client.models.v1alpha1_validating_admission_policy_status import V1alpha1ValidatingAdmissionPolicyStatus
from kubernetes.client.models.v1alpha1_validation import V1alpha1Validation
from kubernetes.client.models.v1alpha1_variable import V1alpha1Variable
from kubernetes.client.models.v1alpha1_volume_attributes_class import V1alpha1VolumeAttributesClass
from kubernetes.client.models.v1alpha1_volume_attributes_class_list import V1alpha1VolumeAttributesClassList
from kubernetes.client.models.v1alpha2_allocation_result import V1alpha2AllocationResult
from kubernetes.client.models.v1alpha2_driver_allocation_result import V1alpha2DriverAllocationResult
from kubernetes.client.models.v1alpha2_driver_requests import V1alpha2DriverRequests
from kubernetes.client.models.v1alpha2_named_resources_allocation_result import V1alpha2NamedResourcesAllocationResult
from kubernetes.client.models.v1alpha2_named_resources_attribute import V1alpha2NamedResourcesAttribute
from kubernetes.client.models.v1alpha2_named_resources_filter import V1alpha2NamedResourcesFilter
from kubernetes.client.models.v1alpha2_named_resources_instance import V1alpha2NamedResourcesInstance
from kubernetes.client.models.v1alpha2_named_resources_int_slice import V1alpha2NamedResourcesIntSlice
from kubernetes.client.models.v1alpha2_named_resources_request import V1alpha2NamedResourcesRequest
from kubernetes.client.models.v1alpha2_named_resources_resources import V1alpha2NamedResourcesResources
from kubernetes.client.models.v1alpha2_named_resources_string_slice import V1alpha2NamedResourcesStringSlice
from kubernetes.client.models.v1alpha2_pod_scheduling_context import V1alpha2PodSchedulingContext
from kubernetes.client.models.v1alpha2_pod_scheduling_context_list import V1alpha2PodSchedulingContextList
from kubernetes.client.models.v1alpha2_pod_scheduling_context_spec import V1alpha2PodSchedulingContextSpec
from kubernetes.client.models.v1alpha2_pod_scheduling_context_status import V1alpha2PodSchedulingContextStatus
from kubernetes.client.models.v1alpha2_resource_claim import V1alpha2ResourceClaim
from kubernetes.client.models.v1alpha2_resource_claim_consumer_reference import V1alpha2ResourceClaimConsumerReference
from kubernetes.client.models.v1alpha2_resource_claim_list import V1alpha2ResourceClaimList
from kubernetes.client.models.v1alpha2_resource_claim_parameters import V1alpha2ResourceClaimParameters
from kubernetes.client.models.v1alpha2_resource_claim_parameters_list import V1alpha2ResourceClaimParametersList
from kubernetes.client.models.v1alpha2_resource_claim_parameters_reference import V1alpha2ResourceClaimParametersReference
from kubernetes.client.models.v1alpha2_resource_claim_scheduling_status import V1alpha2ResourceClaimSchedulingStatus
from kubernetes.client.models.v1alpha2_resource_claim_spec import V1alpha2ResourceClaimSpec
from kubernetes.client.models.v1alpha2_resource_claim_status import V1alpha2ResourceClaimStatus
from kubernetes.client.models.v1alpha2_resource_claim_template import V1alpha2ResourceClaimTemplate
from kubernetes.client.models.v1alpha2_resource_claim_template_list import V1alpha2ResourceClaimTemplateList
from kubernetes.client.models.v1alpha2_resource_claim_template_spec import V1alpha2ResourceClaimTemplateSpec
from kubernetes.client.models.v1alpha2_resource_class import V1alpha2ResourceClass
from kubernetes.client.models.v1alpha2_resource_class_list import V1alpha2ResourceClassList
from kubernetes.client.models.v1alpha2_resource_class_parameters import V1alpha2ResourceClassParameters
from kubernetes.client.models.v1alpha2_resource_class_parameters_list import V1alpha2ResourceClassParametersList
from kubernetes.client.models.v1alpha2_resource_class_parameters_reference import V1alpha2ResourceClassParametersReference
from kubernetes.client.models.v1alpha2_resource_filter import V1alpha2ResourceFilter
from kubernetes.client.models.v1alpha2_resource_handle import V1alpha2ResourceHandle
from kubernetes.client.models.v1alpha2_resource_request import V1alpha2ResourceRequest
from kubernetes.client.models.v1alpha2_resource_slice import V1alpha2ResourceSlice
from kubernetes.client.models.v1alpha2_resource_slice_list import V1alpha2ResourceSliceList
from kubernetes.client.models.v1alpha2_structured_resource_handle import V1alpha2StructuredResourceHandle
from kubernetes.client.models.v1alpha2_vendor_parameters import V1alpha2VendorParameters
from kubernetes.client.models.v1beta1_audit_annotation import V1beta1AuditAnnotation
from kubernetes.client.models.v1beta1_expression_warning import V1beta1ExpressionWarning
from kubernetes.client.models.v1beta1_match_condition import V1beta1MatchCondition
from kubernetes.client.models.v1beta1_match_resources import V1beta1MatchResources
from kubernetes.client.models.v1beta1_named_rule_with_operations import V1beta1NamedRuleWithOperations
from kubernetes.client.models.v1beta1_param_kind import V1beta1ParamKind
from kubernetes.client.models.v1beta1_param_ref import V1beta1ParamRef
from kubernetes.client.models.v1beta1_self_subject_review import V1beta1SelfSubjectReview
from kubernetes.client.models.v1beta1_self_subject_review_status import V1beta1SelfSubjectReviewStatus
from kubernetes.client.models.v1beta1_type_checking import V1beta1TypeChecking
from kubernetes.client.models.v1beta1_validating_admission_policy import V1beta1ValidatingAdmissionPolicy
from kubernetes.client.models.v1beta1_validating_admission_policy_binding import V1beta1ValidatingAdmissionPolicyBinding
from kubernetes.client.models.v1beta1_validating_admission_policy_binding_list import V1beta1ValidatingAdmissionPolicyBindingList
from kubernetes.client.models.v1beta1_validating_admission_policy_binding_spec import V1beta1ValidatingAdmissionPolicyBindingSpec
from kubernetes.client.models.v1beta1_validating_admission_policy_list import V1beta1ValidatingAdmissionPolicyList
from kubernetes.client.models.v1beta1_validating_admission_policy_spec import V1beta1ValidatingAdmissionPolicySpec
from kubernetes.client.models.v1beta1_validating_admission_policy_status import V1beta1ValidatingAdmissionPolicyStatus
from kubernetes.client.models.v1beta1_validation import V1beta1Validation
from kubernetes.client.models.v1beta1_variable import V1beta1Variable
from kubernetes.client.models.v1beta3_exempt_priority_level_configuration import V1beta3ExemptPriorityLevelConfiguration
from kubernetes.client.models.v1beta3_flow_distinguisher_method import V1beta3FlowDistinguisherMethod
from kubernetes.client.models.v1beta3_flow_schema import V1beta3FlowSchema
from kubernetes.client.models.v1beta3_flow_schema_condition import V1beta3FlowSchemaCondition
from kubernetes.client.models.v1beta3_flow_schema_list import V1beta3FlowSchemaList
from kubernetes.client.models.v1beta3_flow_schema_spec import V1beta3FlowSchemaSpec
from kubernetes.client.models.v1beta3_flow_schema_status import V1beta3FlowSchemaStatus
from kubernetes.client.models.v1beta3_group_subject import V1beta3GroupSubject
from kubernetes.client.models.v1beta3_limit_response import V1beta3LimitResponse
from kubernetes.client.models.v1beta3_limited_priority_level_configuration import V1beta3LimitedPriorityLevelConfiguration
from kubernetes.client.models.v1beta3_non_resource_policy_rule import V1beta3NonResourcePolicyRule
from kubernetes.client.models.v1beta3_policy_rules_with_subjects import V1beta3PolicyRulesWithSubjects
from kubernetes.client.models.v1beta3_priority_level_configuration import V1beta3PriorityLevelConfiguration
from kubernetes.client.models.v1beta3_priority_level_configuration_condition import V1beta3PriorityLevelConfigurationCondition
from kubernetes.client.models.v1beta3_priority_level_configuration_list import V1beta3PriorityLevelConfigurationList
from kubernetes.client.models.v1beta3_priority_level_configuration_reference import V1beta3PriorityLevelConfigurationReference
from kubernetes.client.models.v1beta3_priority_level_configuration_spec import V1beta3PriorityLevelConfigurationSpec
from kubernetes.client.models.v1beta3_priority_level_configuration_status import V1beta3PriorityLevelConfigurationStatus
from kubernetes.client.models.v1beta3_queuing_configuration import V1beta3QueuingConfiguration
from kubernetes.client.models.v1beta3_resource_policy_rule import V1beta3ResourcePolicyRule
from kubernetes.client.models.v1beta3_service_account_subject import V1beta3ServiceAccountSubject
from kubernetes.client.models.v1beta3_subject import V1beta3Subject
from kubernetes.client.models.v1beta3_user_subject import V1beta3UserSubject
from kubernetes.client.models.v2_container_resource_metric_source import V2ContainerResourceMetricSource
from kubernetes.client.models.v2_container_resource_metric_status import V2ContainerResourceMetricStatus
from kubernetes.client.models.v2_cross_version_object_reference import V2CrossVersionObjectReference
from kubernetes.client.models.v2_external_metric_source import V2ExternalMetricSource
from kubernetes.client.models.v2_external_metric_status import V2ExternalMetricStatus
from kubernetes.client.models.v2_hpa_scaling_policy import V2HPAScalingPolicy
from kubernetes.client.models.v2_hpa_scaling_rules import V2HPAScalingRules
from kubernetes.client.models.v2_horizontal_pod_autoscaler import V2HorizontalPodAutoscaler
from kubernetes.client.models.v2_horizontal_pod_autoscaler_behavior import V2HorizontalPodAutoscalerBehavior
from kubernetes.client.models.v2_horizontal_pod_autoscaler_condition import V2HorizontalPodAutoscalerCondition
from kubernetes.client.models.v2_horizontal_pod_autoscaler_list import V2HorizontalPodAutoscalerList
from kubernetes.client.models.v2_horizontal_pod_autoscaler_spec import V2HorizontalPodAutoscalerSpec
from kubernetes.client.models.v2_horizontal_pod_autoscaler_status import V2HorizontalPodAutoscalerStatus
from kubernetes.client.models.v2_metric_identifier import V2MetricIdentifier
from kubernetes.client.models.v2_metric_spec import V2MetricSpec
from kubernetes.client.models.v2_metric_status import V2MetricStatus
from kubernetes.client.models.v2_metric_target import V2MetricTarget
from kubernetes.client.models.v2_metric_value_status import V2MetricValueStatus
from kubernetes.client.models.v2_object_metric_source import V2ObjectMetricSource
from kubernetes.client.models.v2_object_metric_status import V2ObjectMetricStatus
from kubernetes.client.models.v2_pods_metric_source import V2PodsMetricSource
from kubernetes.client.models.v2_pods_metric_status import V2PodsMetricStatus
from kubernetes.client.models.v2_resource_metric_source import V2ResourceMetricSource
from kubernetes.client.models.v2_resource_metric_status import V2ResourceMetricStatus
from kubernetes.client.models.version_info import VersionInfo




# coding: utf-8

"""
    Kubernetes

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: release-1.30
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from kubernetes.client.configuration import Configuration


class V1ManagedFieldsEntry(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'api_version': 'str',
        'fields_type': 'str',
        'fields_v1': 'object',
        'manager': 'str',
        'operation': 'str',
        'subresource': 'str',
        'time': 'datetime'
    }

    attribute_map = {
        'api_version': 'apiVersion',
        'fields_type': 'fieldsType',
        'fields_v1': 'fieldsV1',
        'manager': 'manager',
        'operation': 'operation',
        'subresource': 'subresource',
        'time': 'time'
    }

    def __init__(self, api_version=None, fields_type=None, fields_v1=None, manager=None, operation=None, subresource=None, time=None, local_vars_configuration=None):  # noqa: E501
        """V1ManagedFieldsEntry - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._api_version = None
        self._fields_type = None
        self._fields_v1 = None
        self._manager = None
        self._operation = None
        self._subresource = None
        self._time = None
        self.discriminator = None

        if api_version is not None:
            self.api_version = api_version
        if fields_type is not None:
            self.fields_type = fields_type
        if fields_v1 is not None:
            self.fields_v1 = fields_v1
        if manager is not None:
            self.manager = manager
        if operation is not None:
            self.operation = operation
        if subresource is not None:
            self.subresource = subresource
        if time is not None:
            self.time = time

    @property
    def api_version(self):
        """Gets the api_version of this V1ManagedFieldsEntry.  # noqa: E501

        APIVersion defines the version of this resource that this field set applies to. The format is \"group/version\" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted.  # noqa: E501

        :return: The api_version of this V1ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._api_version

    @api_version.setter
    def api_version(self, api_version):
        """Sets the api_version of this V1ManagedFieldsEntry.

        APIVersion defines the version of this resource that this field set applies to. The format is \"group/version\" just like the top-level APIVersion field. It is necessary to track the version of a field set because it cannot be automatically converted.  # noqa: E501

        :param api_version: The api_version of this V1ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._api_version = api_version

    @property
    def fields_type(self):
        """Gets the fields_type of this V1ManagedFieldsEntry.  # noqa: E501

        FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: \"FieldsV1\"  # noqa: E501

        :return: The fields_type of this V1ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._fields_type

    @fields_type.setter
    def fields_type(self, fields_type):
        """Sets the fields_type of this V1ManagedFieldsEntry.

        FieldsType is the discriminator for the different fields format and version. There is currently only one possible value: \"FieldsV1\"  # noqa: E501

        :param fields_type: The fields_type of this V1ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._fields_type = fields_type

    @property
    def fields_v1(self):
        """Gets the fields_v1 of this V1ManagedFieldsEntry.  # noqa: E501

        FieldsV1 holds the first JSON version format as described in the \"FieldsV1\" type.  # noqa: E501

        :return: The fields_v1 of this V1ManagedFieldsEntry.  # noqa: E501
        :rtype: object
        """
        return self._fields_v1

    @fields_v1.setter
    def fields_v1(self, fields_v1):
        """Sets the fields_v1 of this V1ManagedFieldsEntry.

        FieldsV1 holds the first JSON version format as described in the \"FieldsV1\" type.  # noqa: E501

        :param fields_v1: The fields_v1 of this V1ManagedFieldsEntry.  # noqa: E501
        :type: object
        """

        self._fields_v1 = fields_v1

    @property
    def manager(self):
        """Gets the manager of this V1ManagedFieldsEntry.  # noqa: E501

        Manager is an identifier of the workflow managing these fields.  # noqa: E501

        :return: The manager of this V1ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._manager

    @manager.setter
    def manager(self, manager):
        """Sets the manager of this V1ManagedFieldsEntry.

        Manager is an identifier of the workflow managing these fields.  # noqa: E501

        :param manager: The manager of this V1ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._manager = manager

    @property
    def operation(self):
        """Gets the operation of this V1ManagedFieldsEntry.  # noqa: E501

        Operation is the type of operation which lead to this ManagedFieldsEntry being created. The only valid values for this field are 'Apply' and 'Update'.  # noqa: E501

        :return: The operation of this V1ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """Sets the operation of this V1ManagedFieldsEntry.

        Operation is the type of operation which lead to this ManagedFieldsEntry being created. The only valid values for this field are 'Apply' and 'Update'.  # noqa: E501

        :param operation: The operation of this V1ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._operation = operation

    @property
    def subresource(self):
        """Gets the subresource of this V1ManagedFieldsEntry.  # noqa: E501

        Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource. The value of this field is used to distinguish between managers, even if they share the same name. For example, a status update will be distinct from a regular update using the same manager name. Note that the APIVersion field is not related to the Subresource field and it always corresponds to the version of the main resource.  # noqa: E501

        :return: The subresource of this V1ManagedFieldsEntry.  # noqa: E501
        :rtype: str
        """
        return self._subresource

    @subresource.setter
    def subresource(self, subresource):
        """Sets the subresource of this V1ManagedFieldsEntry.

        Subresource is the name of the subresource used to update that object, or empty string if the object was updated through the main resource. The value of this field is used to distinguish between managers, even if they share the same name. For example, a status update will be distinct from a regular update using the same manager name. Note that the APIVersion field is not related to the Subresource field and it always corresponds to the version of the main resource.  # noqa: E501

        :param subresource: The subresource of this V1ManagedFieldsEntry.  # noqa: E501
        :type: str
        """

        self._subresource = subresource

    @property
    def time(self):
        """Gets the time of this V1ManagedFieldsEntry.  # noqa: E501

        Time is the timestamp of when the ManagedFields entry was added. The timestamp will also be updated if a field is added, the manager changes any of the owned fields value or removes a field. The timestamp does not update when a field is removed from the entry because another manager took it over.  # noqa: E501

        :return: The time of this V1ManagedFieldsEntry.  # noqa: E501
        :rtype: datetime
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this V1ManagedFieldsEntry.

        Time is the timestamp of when the ManagedFields entry was added. The timestamp will also be updated if a field is added, the manager changes any of the owned fields value or removes a field. The timestamp does not update when a field is removed from the entry because another manager took it over.  # noqa: E501

        :param time: The time of this V1ManagedFieldsEntry.  # noqa: E501
        :type: datetime
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1ManagedFieldsEntry):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1ManagedFieldsEntry):
            return True

        return self.to_dict() != other.to_dict()
